[evolution/wip/mcrha/eds-libical-glib] Adapt to the recent libical-glib and eds API changes
- From: Milan Crha <mcrha src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [evolution/wip/mcrha/eds-libical-glib] Adapt to the recent libical-glib and eds API changes
- Date: Fri, 22 Mar 2019 11:51:29 +0000 (UTC)
commit 5d3a5e0697737083912344fa0812ac0f6fbf3750
Author: Milan Crha <mcrha redhat com>
Date: Fri Mar 22 12:52:09 2019 +0100
Adapt to the recent libical-glib and eds API changes
This is for bare structure wrappers rename and addition of some _inplace()
helper functions.
src/calendar/gui/calendar-config.c | 2 +-
src/calendar/gui/comp-util.c | 78 ++++++++++-----------
src/calendar/gui/comp-util.h | 8 +--
src/calendar/gui/e-alarm-list.c | 22 +++---
src/calendar/gui/e-cal-component-preview.c | 8 +--
src/calendar/gui/e-cal-data-model.c | 10 +--
src/calendar/gui/e-cal-dialogs.c | 16 ++---
src/calendar/gui/e-cal-list-view.c | 6 +-
src/calendar/gui/e-cal-model-calendar.c | 4 +-
src/calendar/gui/e-cal-model-memos.c | 7 +-
src/calendar/gui/e-cal-model-tasks.c | 24 +++----
src/calendar/gui/e-cal-model.c | 30 ++++-----
src/calendar/gui/e-cal-model.h | 4 +-
src/calendar/gui/e-calendar-view.c | 56 +++++++--------
src/calendar/gui/e-cell-date-edit-text.c | 36 +++++-----
src/calendar/gui/e-cell-date-edit-text.h | 10 +--
src/calendar/gui/e-comp-editor-page-recurrence.c | 2 +-
src/calendar/gui/e-comp-editor-property-part.h | 10 +--
src/calendar/gui/e-date-time-list.c | 30 ++++-----
src/calendar/gui/e-date-time-list.h | 6 +-
src/calendar/gui/e-day-view-main-item.c | 6 +-
src/calendar/gui/e-day-view-time-item.c | 14 ++--
src/calendar/gui/e-day-view-top-item.c | 4 +-
src/calendar/gui/e-day-view.c | 56 +++++++--------
src/calendar/gui/e-memo-table.c | 8 +--
src/calendar/gui/e-send-options-utils.c | 4 +-
src/calendar/gui/e-task-table.c | 8 +--
src/calendar/gui/e-to-do-pane.c | 86 ++++++++++++------------
src/calendar/gui/e-week-view-main-item.c | 8 +--
src/calendar/gui/e-week-view.c | 20 +++---
src/calendar/gui/itip-utils.c | 40 +++++------
src/calendar/gui/tag-calendar.c | 36 +++++-----
src/calendar/importers/icalendar-importer.c | 22 +++---
src/e-util/e-timezone-dialog.c | 4 +-
src/modules/alarm-notify/alarm-notify.c | 2 +-
src/modules/calendar/e-cal-shell-view-private.c | 2 +-
src/modules/itip-formatter/itip-view.c | 4 +-
src/plugins/save-calendar/csv-format.c | 2 +-
src/plugins/save-calendar/rdf-format.c | 2 +-
39 files changed, 348 insertions(+), 349 deletions(-)
---
diff --git a/src/calendar/gui/calendar-config.c b/src/calendar/gui/calendar-config.c
index 40d94384de..d523d5f846 100644
--- a/src/calendar/gui/calendar-config.c
+++ b/src/calendar/gui/calendar-config.c
@@ -229,7 +229,7 @@ calendar_config_get_hide_completed_tasks_sexp (gboolean get_completed)
} else {
gchar *isodate;
ICalTimezone *zone;
- ICalTimetype *tt;
+ ICalTime *tt;
time_t t;
/* Get the current time, and subtract the appropriate
diff --git a/src/calendar/gui/comp-util.c b/src/calendar/gui/comp-util.c
index fd82663867..00295acb0f 100644
--- a/src/calendar/gui/comp-util.c
+++ b/src/calendar/gui/comp-util.c
@@ -318,7 +318,7 @@ cal_comp_event_new_with_defaults_sync (ECalClient *client,
ECalComponent *comp;
ECalComponentAlarm *alarm;
ICalProperty *prop;
- ICalDurationType *duration;
+ ICalDuration *duration;
ECalComponentAlarmTrigger *trigger;
if (client && !e_cal_client_get_default_object_sync (client, &icomp, cancellable, error))
@@ -349,20 +349,20 @@ cal_comp_event_new_with_defaults_sync (ECalClient *client,
e_cal_component_alarm_set_action (alarm, E_CAL_COMPONENT_ALARM_DISPLAY);
- duration = i_cal_duration_type_null_duration ();
- i_cal_duration_type_set_is_neg (duration, TRUE);
+ duration = i_cal_duration_null_duration ();
+ i_cal_duration_set_is_neg (duration, TRUE);
switch (default_reminder_units) {
case E_DURATION_MINUTES:
- i_cal_duration_type_set_minutes (duration, default_reminder_interval);
+ i_cal_duration_set_minutes (duration, default_reminder_interval);
break;
case E_DURATION_HOURS:
- i_cal_duration_type_set_hours (duration, default_reminder_interval);
+ i_cal_duration_set_hours (duration, default_reminder_interval);
break;
case E_DURATION_DAYS:
- i_cal_duration_type_set_days (duration, default_reminder_interval);
+ i_cal_duration_set_days (duration, default_reminder_interval);
break;
default:
@@ -390,7 +390,7 @@ cal_comp_event_new_with_current_time_sync (ECalClient *client,
GError **error)
{
ECalComponent *comp;
- ICalTimetype *itt;
+ ICalTime *itt;
ECalComponentDateTime *dt;
ICalTimezone *zone;
@@ -412,7 +412,7 @@ cal_comp_event_new_with_current_time_sync (ECalClient *client,
e_cal_component_set_dtend (comp, dt);
} else {
itt = i_cal_time_current_time_with_zone (zone);
- i_cal_time_adjust (itt, 0, 1, -i_cal_timetype_get_minute (itt), -i_cal_timetype_get_second
(itt));
+ i_cal_time_adjust (itt, 0, 1, -i_cal_time_get_minute (itt), -i_cal_time_get_second (itt));
dt = e_cal_component_datetime_new_take (itt, zone ? g_strdup (i_cal_timezone_get_tzid (zone))
: NULL);
@@ -497,7 +497,7 @@ cal_comp_update_time_by_active_window (ECalComponent *comp,
ECalendarView *cal_view;
time_t start = 0, end = 0;
ICalTimezone *zone;
- ICalTimetype *itt;
+ ICalTime *itt;
ICalComponent *icomp;
ICalProperty *prop;
@@ -798,11 +798,11 @@ comp_util_sanitize_recurrence_master_sync (ECalComponent *comp,
return FALSE;
}
- i_cal_timetype_get_date (e_cal_component_datetime_get_value (msdt), &yy, &mm, &dd);
- i_cal_timetype_set_date (e_cal_component_datetime_get_value (sdt), yy, mm, dd);
+ i_cal_time_get_date (e_cal_component_datetime_get_value (msdt), &yy, &mm, &dd);
+ i_cal_time_set_date (e_cal_component_datetime_get_value (sdt), yy, mm, dd);
- i_cal_timetype_get_date (e_cal_component_datetime_get_value (medt), &yy, &mm, &dd);
- i_cal_timetype_set_date (e_cal_component_datetime_get_value (edt), yy, mm, dd);
+ i_cal_time_get_date (e_cal_component_datetime_get_value (medt), &yy, &mm, &dd);
+ i_cal_time_set_date (e_cal_component_datetime_get_value (edt), yy, mm, dd);
e_cal_component_set_dtstart (comp, sdt);
e_cal_component_set_dtend (comp, edt);
@@ -853,11 +853,11 @@ void
cal_comp_get_instance_times (ECalClient *client,
ICalComponent *icomp,
const ICalTimezone *default_zone,
- ICalTimetype **out_instance_start,
- ICalTimetype **out_instance_end,
+ ICalTime **out_instance_start,
+ ICalTime **out_instance_end,
GCancellable *cancellable)
{
- ICalTimetype *start_time, *end_time;
+ ICalTime *start_time, *end_time;
const ICalTimezone *zone = default_zone;
g_return_if_fail (E_IS_CAL_CLIENT (client));
@@ -872,11 +872,11 @@ cal_comp_get_instance_times (ECalClient *client,
if (!end_time || i_cal_time_is_null_time (end_time)) {
g_clear_object (&end_time);
- end_time = i_cal_timetype_new_clone (start_time);
+ end_time = i_cal_time_new_clone (start_time);
}
- if (i_cal_timetype_get_zone (start_time)) {
- zone = i_cal_timetype_get_zone (start_time);
+ if (i_cal_time_get_timezone (start_time)) {
+ zone = i_cal_time_get_timezone (start_time);
} else {
ICalParameter *param = NULL;
ICalProperty *prop = i_cal_component_get_first_property (icomp, I_CAL_DTSTART_PROPERTY);
@@ -902,11 +902,11 @@ cal_comp_get_instance_times (ECalClient *client,
}
}
- *out_instance_start = i_cal_timetype_new_clone (start_time);
- i_cal_timetype_set_zone (*out_instance_start, zone);
+ *out_instance_start = i_cal_time_new_clone (start_time);
+ i_cal_time_set_timezone (*out_instance_start, zone);
- if (i_cal_timetype_get_zone (end_time)) {
- zone = i_cal_timetype_get_zone (end_time);
+ if (i_cal_time_get_timezone (end_time)) {
+ zone = i_cal_time_get_timezone (end_time);
} else {
ICalParameter *param = NULL;
ICalProperty *prop = i_cal_component_get_first_property (icomp, I_CAL_DTEND_PROPERTY);
@@ -935,8 +935,8 @@ cal_comp_get_instance_times (ECalClient *client,
}
}
- *out_instance_end = i_cal_timetype_new_clone (end_time);
- i_cal_timetype_set_zone (*out_instance_end, zone);
+ *out_instance_end = i_cal_time_new_clone (end_time);
+ i_cal_time_set_timezone (*out_instance_end, zone);
g_clear_object (&start_time);
g_clear_object (&end_time);
@@ -947,7 +947,7 @@ cal_comp_gdate_to_timet (const GDate *date,
const ICalTimezone *with_zone)
{
struct tm tm;
- ICalTimetype *tt;
+ ICalTime *tt;
time_t res;
g_return_val_if_fail (date != NULL, (time_t) -1);
@@ -955,7 +955,7 @@ cal_comp_gdate_to_timet (const GDate *date,
g_date_to_struct_tm (date, &tm);
- tt = tm_to_icaltimetype (&tm, TRUE);
+ tt = e_cal_util_tm_to_i_cal_time (&tm, TRUE);
if (with_zone)
res = i_cal_time_as_timet_with_zone (tt, (ICalTimezone *) with_zone);
else
@@ -1343,24 +1343,24 @@ cal_comp_transfer_item_to_sync (ECalClient *src_client,
void
cal_comp_util_update_tzid_parameter (ICalProperty *prop,
- const ICalTimetype *tt)
+ const ICalTime *tt)
{
ICalParameter *param;
const gchar *tzid = NULL;
g_return_if_fail (prop != NULL);
- if (!tt || !i_cal_time_is_valid_time ((ICalTimetype *) tt) ||
- i_cal_time_is_null_time ((ICalTimetype *) tt))
+ if (!tt || !i_cal_time_is_valid_time ((ICalTime *) tt) ||
+ i_cal_time_is_null_time ((ICalTime *) tt))
return;
param = i_cal_property_get_first_parameter (prop, I_CAL_TZID_PARAMETER);
- if (i_cal_timetype_get_zone ((ICalTimetype *) tt))
- tzid = i_cal_timezone_get_tzid (i_cal_timetype_get_zone ((ICalTimetype *) tt));
+ if (i_cal_time_get_timezone ((ICalTime *) tt))
+ tzid = i_cal_timezone_get_tzid (i_cal_time_get_timezone ((ICalTime *) tt));
- if (i_cal_timetype_get_zone ((ICalTimetype *) tt) && tzid && *tzid &&
- !i_cal_time_is_utc ((ICalTimetype *) tt) &&
- !i_cal_time_is_date ((ICalTimetype *) tt)) {
+ if (i_cal_time_get_timezone ((ICalTime *) tt) && tzid && *tzid &&
+ !i_cal_time_is_utc ((ICalTime *) tt) &&
+ !i_cal_time_is_date ((ICalTime *) tt)) {
if (param) {
i_cal_parameter_set_tzid (param, (gchar *) tzid);
g_object_unref (param);
@@ -1376,9 +1376,9 @@ cal_comp_util_update_tzid_parameter (ICalProperty *prop,
/* Returns <0 for time before today, 0 for today, >0 for after today (future) */
gint
-cal_comp_util_compare_time_with_today (const ICalTimetype *time_tt)
+cal_comp_util_compare_time_with_today (const ICalTime *time_tt)
{
- ICalTimetype *now_tt, *tt = (ICalTimetype *) time_tt;
+ ICalTime *now_tt, *tt = (ICalTime *) time_tt;
gint res;
if (!tt || i_cal_time_is_null_time (tt))
@@ -1388,8 +1388,8 @@ cal_comp_util_compare_time_with_today (const ICalTimetype *time_tt)
now_tt = i_cal_time_today ();
res = i_cal_time_compare_date_only (tt, now_tt);
} else {
- now_tt = i_cal_time_current_time_with_zone (i_cal_timetype_get_zone (tt));
- i_cal_timetype_set_zone (now_tt, i_cal_timetype_get_zone (tt));
+ now_tt = i_cal_time_current_time_with_zone (i_cal_time_get_timezone (tt));
+ i_cal_time_set_timezone (now_tt, i_cal_time_get_timezone (tt));
res = i_cal_time_compare (tt, now_tt);
}
diff --git a/src/calendar/gui/comp-util.h b/src/calendar/gui/comp-util.h
index 1236afde04..b6ae7dc617 100644
--- a/src/calendar/gui/comp-util.h
+++ b/src/calendar/gui/comp-util.h
@@ -113,8 +113,8 @@ gchar * comp_util_suggest_filename (ICalComponent *icomp,
void cal_comp_get_instance_times (ECalClient *client,
ICalComponent *icomp,
const ICalTimezone *default_zone,
- ICalTimetype **out_instance_start,
- ICalTimetype **out_instance_end,
+ ICalTime **out_instance_start,
+ ICalTime **out_instance_end,
GCancellable *cancellable);
time_t cal_comp_gdate_to_timet (const GDate *date,
const ICalTimezone *with_zone);
@@ -137,9 +137,9 @@ gboolean cal_comp_transfer_item_to_sync (ECalClient *src_client,
GError **error);
void cal_comp_util_update_tzid_parameter
(ICalProperty *prop,
- const ICalTimetype *tt);
+ const ICalTime *tt);
gint cal_comp_util_compare_time_with_today
- (const ICalTimetype *time_tt);
+ (const ICalTime *time_tt);
gboolean cal_comp_util_have_in_new_attendees
(const GSList *new_attendees_mails,
const gchar *eml);
diff --git a/src/calendar/gui/e-alarm-list.c b/src/calendar/gui/e-alarm-list.c
index 1d80e8ec3b..9ca111ee74 100644
--- a/src/calendar/gui/e-alarm-list.c
+++ b/src/calendar/gui/e-alarm-list.c
@@ -355,7 +355,7 @@ e_alarm_list_get_path (GtkTreeModel *tree_model,
/* Builds a string for the duration of the alarm. If the duration is zero, returns NULL. */
static gchar *
-get_alarm_duration_string (ICalDurationType *duration)
+get_alarm_duration_string (ICalDuration *duration)
{
GString *string = g_string_new (NULL);
gboolean have_something;
@@ -363,35 +363,35 @@ get_alarm_duration_string (ICalDurationType *duration)
have_something = FALSE;
- value = i_cal_duration_type_get_days (duration);
+ value = i_cal_duration_get_days (duration);
if (value >= 1) {
/* Translator: Entire string is like "Pop up an alert %d days before start" */
g_string_printf (string, ngettext ("%d day", "%d days", value), value);
have_something = TRUE;
}
- value = i_cal_duration_type_get_weeks (duration);
+ value = i_cal_duration_get_weeks (duration);
if (value >= 1) {
/* Translator: Entire string is like "Pop up an alert %d weeks before start" */
g_string_printf (string, ngettext ("%d week","%d weeks", value), value);
have_something = TRUE;
}
- value = i_cal_duration_type_get_hours (duration);
+ value = i_cal_duration_get_hours (duration);
if (value >= 1) {
/* Translator: Entire string is like "Pop up an alert %d hours before start" */
g_string_printf (string, ngettext ("%d hour", "%d hours", value), value);
have_something = TRUE;
}
- value = i_cal_duration_type_get_minutes (duration);
+ value = i_cal_duration_get_minutes (duration);
if (value >= 1) {
/* Translator: Entire string is like "Pop up an alert %d minutes before start" */
g_string_printf (string, ngettext ("%d minute", "%d minutes", value), value);
have_something = TRUE;
}
- value = i_cal_duration_type_get_seconds (duration);
+ value = i_cal_duration_get_seconds (duration);
if (value >= 1) {
/* Translator: Entire string is like "Pop up an alert %d seconds before start" */
g_string_printf (string, ngettext ("%d second", "%d seconds", value), value);
@@ -406,7 +406,7 @@ get_alarm_string (ECalComponentAlarm *alarm)
{
ECalComponentAlarmAction action;
ECalComponentAlarmTrigger *trigger;
- ICalDurationType *duration;
+ ICalDuration *duration;
const gchar *base;
gchar *str = NULL, *dur;
@@ -445,7 +445,7 @@ get_alarm_string (ECalComponentAlarm *alarm)
dur = get_alarm_duration_string (duration);
if (dur) {
- if (i_cal_duration_type_is_neg (duration))
+ if (i_cal_duration_is_neg (duration))
str = g_strdup_printf (
/*Translator: The first %s refers to the base, which would be actions
like
* "Play a Sound". Second %s refers to the duration string e.g:"15
minutes"*/
@@ -471,7 +471,7 @@ get_alarm_string (ECalComponentAlarm *alarm)
dur = get_alarm_duration_string (duration);
if (dur) {
- if (i_cal_duration_type_is_neg (duration))
+ if (i_cal_duration_is_neg (duration))
str = g_strdup_printf (
/* Translator: The first %s refers to the base, which would be
actions like
* "Play a Sound". Second %s refers to the duration string e.g:"15
minutes" */
@@ -493,7 +493,7 @@ get_alarm_string (ECalComponentAlarm *alarm)
break;
case E_CAL_COMPONENT_ALARM_TRIGGER_ABSOLUTE: {
- ICalTimetype *itt;
+ ICalTime *itt;
ICalTimezone *utc_zone, *current_zone;
struct tm tm;
gchar buf[256];
@@ -505,7 +505,7 @@ get_alarm_string (ECalComponentAlarm *alarm)
utc_zone = i_cal_timezone_get_utc_timezone ();
current_zone = calendar_config_get_icaltimezone ();
- tm = icaltimetype_to_tm_with_zone (itt, utc_zone, current_zone);
+ tm = e_cal_util_i_cal_time_to_tm_with_zone (itt, utc_zone, current_zone);
e_time_format_date_and_time (&tm, calendar_config_get_24_hour_format (),
FALSE, FALSE, buf, sizeof (buf));
diff --git a/src/calendar/gui/e-cal-component-preview.c b/src/calendar/gui/e-cal-component-preview.c
index b0354baa60..39308ffb9f 100644
--- a/src/calendar/gui/e-cal-component-preview.c
+++ b/src/calendar/gui/e-cal-component-preview.c
@@ -48,7 +48,7 @@ struct _ECalComponentPreviewPrivate {
* if it didn't change then the preview is not updated */
gchar *cal_uid;
gchar *comp_uid;
- ICalTimetype *comp_last_modified;
+ ICalTime *comp_last_modified;
gint comp_sequence;
ECalClient *client;
@@ -111,7 +111,7 @@ update_comp_info (ECalComponentPreview *preview,
const gchar *uid;
gchar *cal_uid;
gchar *comp_uid;
- ICalTimetype *comp_last_modified;
+ ICalTime *comp_last_modified;
gint comp_sequence;
source = e_client_get_source (E_CLIENT (client));
@@ -155,7 +155,7 @@ timet_to_str_with_zone (ECalComponentDateTime *dt,
ECalClient *client,
ICalTimezone *default_zone)
{
- ICalTimetype *itt;
+ ICalTime *itt;
ICalTimezone *zone = NULL;
struct tm tm;
@@ -172,7 +172,7 @@ timet_to_str_with_zone (ECalComponentDateTime *dt,
if (zone != NULL)
i_cal_timezone_convert_time (itt, zone, default_zone);
- tm = icaltimetype_to_tm (itt);
+ tm = e_cal_util_i_cal_time_to_tm (itt);
return e_datetime_format_format_tm ("calendar", "table", i_cal_time_is_date (itt) ? DTFormatKindDate
: DTFormatKindDateTime, &tm);
}
diff --git a/src/calendar/gui/e-cal-data-model.c b/src/calendar/gui/e-cal-data-model.c
index 5eba636f0d..6bb91c1f7d 100644
--- a/src/calendar/gui/e-cal-data-model.c
+++ b/src/calendar/gui/e-cal-data-model.c
@@ -139,7 +139,7 @@ component_data_equal (ComponentData *comp_data1,
ComponentData *comp_data2)
{
ICalComponent *icomp1, *icomp2;
- ICalTimetype *tt1, *tt2;
+ ICalTime *tt1, *tt2;
gchar *as_str1, *as_str2;
gboolean equal;
@@ -1093,8 +1093,8 @@ typedef struct
static gboolean
cal_data_model_instance_generated (ICalComponent *icomp,
- ICalTimetype *instance_start,
- ICalTimetype *instance_end,
+ ICalTime *instance_start,
+ ICalTime *instance_end,
gpointer user_data,
GCancellable *cancellable,
GError **error)
@@ -1102,7 +1102,7 @@ cal_data_model_instance_generated (ICalComponent *icomp,
GenerateInstancesData *gid = user_data;
ComponentData *comp_data;
ECalComponent *comp_copy;
- ICalTimetype *tt, *tt2;
+ ICalTime *tt, *tt2;
time_t start_tt, end_tt;
g_return_val_if_fail (gid != NULL, FALSE);
@@ -1310,7 +1310,7 @@ cal_data_model_process_modified_or_added_objects (ECalClientView *view,
/* Single or detached instance, the simple case */
ECalComponent *comp;
ComponentData *comp_data;
- ICalTimetype *start_tt = NULL, *end_tt = NULL;
+ ICalTime *start_tt = NULL, *end_tt = NULL;
time_t instance_start, instance_end;
if (data_model->priv->skip_cancelled &&
diff --git a/src/calendar/gui/e-cal-dialogs.c b/src/calendar/gui/e-cal-dialogs.c
index e048c170c3..e984edf055 100644
--- a/src/calendar/gui/e-cal-dialogs.c
+++ b/src/calendar/gui/e-cal-dialogs.c
@@ -631,14 +631,14 @@ ecal_event (ECalendarItem *calitem,
{
GoToDialog *dlg = user_data;
GDate start_date, end_date;
- ICalTimetype *tt = i_cal_time_null_time ();
+ ICalTime *tt = i_cal_time_null_time ();
ICalTimezone *timezone;
time_t et;
g_warn_if_fail (e_calendar_item_get_selection (calitem, &start_date, &end_date));
timezone = e_cal_data_model_get_timezone (dlg->data_model);
- i_cal_timetype_set_date (tt,
+ i_cal_time_set_date (tt,
g_date_get_year (&start_date),
g_date_get_month (&start_date),
g_date_get_day (&start_date));
@@ -659,7 +659,7 @@ get_current_time (ECalendarItem *calitem,
gpointer data)
{
ICalTimezone *zone;
- ICalTimetype *tt;
+ ICalTime *tt;
struct tm tmp_tm = { 0 };
/* Get the current timezone. */
@@ -667,7 +667,7 @@ get_current_time (ECalendarItem *calitem,
tt = i_cal_time_from_timet_with_zone (time (NULL), FALSE, zone);
- tmp_tm = icaltimetype_to_tm (tt);
+ tmp_tm = e_cal_util_i_cal_time_to_tm (tt);
g_clear_object (&tt);
@@ -785,15 +785,15 @@ e_cal_dialogs_goto_run (GtkWindow *parent,
dlg->month_val = g_date_get_month (from_date) - 1;
dlg->day_val = g_date_get_day (from_date);
} else {
- ICalTimetype *tt;
+ ICalTime *tt;
ICalTimezone *timezone;
timezone = e_cal_data_model_get_timezone (dlg->data_model);
tt = i_cal_time_current_time_with_zone (timezone);
- dlg->year_val = i_cal_timetype_get_year (tt);
- dlg->month_val = i_cal_timetype_get_month (tt) - 1;
- dlg->day_val = i_cal_timetype_get_day (tt);
+ dlg->year_val = i_cal_time_get_year (tt);
+ dlg->month_val = i_cal_time_get_month (tt) - 1;
+ dlg->day_val = i_cal_time_get_day (tt);
g_clear_object (&tt);
}
diff --git a/src/calendar/gui/e-cal-list-view.c b/src/calendar/gui/e-cal-list-view.c
index 2c13250a6c..134f5978cb 100644
--- a/src/calendar/gui/e-cal-list-view.c
+++ b/src/calendar/gui/e-cal-list-view.c
@@ -135,13 +135,13 @@ get_current_time_cb (ECellDateEdit *ecde,
{
ECalListView *cal_list_view = data;
ICalTimezone *zone;
- ICalTimetype *tt;
+ ICalTime *tt;
struct tm tmp_tm;
zone = e_calendar_view_get_timezone (E_CALENDAR_VIEW (cal_list_view));
tt = i_cal_time_from_timet_with_zone (time (NULL), FALSE, zone);
- tmp_tm = icaltimetype_to_tm (tt);
+ tmp_tm = e_cal_util_i_cal_time_to_tm (tt);
g_clear_object (&tt);
@@ -579,7 +579,7 @@ e_cal_list_view_get_selected_events (ECalendarView *cal_view)
/* It also frees 'itt' */
static void
-adjust_range (ICalTimetype *itt,
+adjust_range (ICalTime *itt,
time_t *earliest,
time_t *latest,
gboolean *set)
diff --git a/src/calendar/gui/e-cal-model-calendar.c b/src/calendar/gui/e-cal-model-calendar.c
index 0fbb100ed3..cac1fe3fc0 100644
--- a/src/calendar/gui/e-cal-model-calendar.c
+++ b/src/calendar/gui/e-cal-model-calendar.c
@@ -49,7 +49,7 @@ static ECellDateEditValue *
get_dtend (ECalModelCalendar *model,
ECalModelComponent *comp_data)
{
- ICalTimetype *tt_end;
+ ICalTime *tt_end;
if (!comp_data->dtend) {
ICalProperty *prop;
@@ -86,7 +86,7 @@ get_dtend (ECalModelCalendar *model,
if (i_cal_time_is_date (tt_end) &&
(prop = i_cal_component_get_first_property (comp_data->icalcomp, I_CAL_DTSTART_PROPERTY))
!= NULL) {
- ICalTimetype *tt_start;
+ ICalTime *tt_start;
ICalTimezone *start_zone = NULL;
gboolean got_start_zone = FALSE;
diff --git a/src/calendar/gui/e-cal-model-memos.c b/src/calendar/gui/e-cal-model-memos.c
index bfa6ec3ecd..7a19dce3d6 100644
--- a/src/calendar/gui/e-cal-model-memos.c
+++ b/src/calendar/gui/e-cal-model-memos.c
@@ -64,20 +64,21 @@ cal_model_memos_fill_component_from_values (ECalModel *model,
ECalModelComponent *comp_data,
GHashTable *values)
{
- ICalTimetype *dtstart;
+ ICalTime *dtstart;
g_return_if_fail (E_IS_CAL_MODEL_MEMOS (model));
g_return_if_fail (comp_data != NULL);
g_return_if_fail (values != NULL);
dtstart = i_cal_component_get_dtstart (comp_data->icalcomp);
- if (i_cal_time_is_null_time (dtstart) || !i_cal_time_is_valid_time (dtstart)) {
+ if (!dtstart || i_cal_time_is_null_time (dtstart) || !i_cal_time_is_valid_time (dtstart)) {
g_clear_object (&dtstart);
dtstart = i_cal_time_today ();
i_cal_component_set_dtstart (comp_data->icalcomp, dtstart);
- g_clear_object (&dtstart);
}
+
+ g_clear_object (&dtstart);
}
static gint
diff --git a/src/calendar/gui/e-cal-model-tasks.c b/src/calendar/gui/e-cal-model-tasks.c
index 7e3a522e3e..978f530361 100644
--- a/src/calendar/gui/e-cal-model-tasks.c
+++ b/src/calendar/gui/e-cal-model-tasks.c
@@ -135,7 +135,7 @@ static ECellDateEditValue *
get_completed (ECalModelComponent *comp_data)
{
if (!comp_data->completed) {
- ICalTimetype *tt_completed;
+ ICalTime *tt_completed;
ICalTimezone *zone = NULL;
ICalProperty *prop;
@@ -165,7 +165,7 @@ static ECellDateEditValue *
get_due (ECalModelComponent *comp_data)
{
if (!comp_data->due) {
- ICalTimetype *tt_due;
+ ICalTime *tt_due;
ICalTimezone *zone = NULL;
ICalProperty *prop;
@@ -196,7 +196,7 @@ static gpointer
get_geo (ECalModelComponent *comp_data)
{
ICalProperty *prop;
- ICalGeoType *geo = NULL;
+ ICalGeo *geo = NULL;
static gchar buf[32];
prop = i_cal_component_get_first_property (comp_data->icalcomp, I_CAL_GEO_PROPERTY);
@@ -205,10 +205,10 @@ get_geo (ECalModelComponent *comp_data)
if (geo) {
g_snprintf (
buf, sizeof (buf), "%g %s, %g %s",
- fabs (i_cal_geo_type_get_lat (geo)),
- i_cal_geo_type_get_lat (geo) >= 0.0 ? "N" : "S",
- fabs (i_cal_geo_type_get_lon (geo)),
- i_cal_geo_type_get_lon (geo) >= 0.0 ? "E" : "W");
+ fabs (i_cal_geo_get_lat (geo)),
+ i_cal_geo_get_lat (geo) >= 0.0 ? "N" : "S",
+ fabs (i_cal_geo_get_lon (geo)),
+ i_cal_geo_get_lon (geo) >= 0.0 ? "E" : "W");
g_object_unref (prop);
g_object_unref (geo);
return buf;
@@ -378,7 +378,7 @@ get_due_status (ECalModelTasks *model,
if (!prop)
return E_CAL_MODEL_TASKS_DUE_NEVER;
else {
- ICalTimetype *now_tt, *due_tt;
+ ICalTime *now_tt, *due_tt;
ICalTimezone *zone = NULL;
/* Second, is it already completed? */
@@ -473,14 +473,14 @@ set_completed (ECalModelTasks *model,
if (!dv)
ensure_task_not_complete (comp_data, TRUE);
else {
- ICalTimetype *tt;
+ ICalTime *tt;
time_t t;
tt = e_cell_date_edit_value_get_time (dv);
if (i_cal_time_is_date (tt)) {
/* if it's a date, it will be floating,
* but completed needs a date time value */
- i_cal_timetype_set_is_date (tt, FALSE);
+ i_cal_time_set_is_date (tt, FALSE);
t = i_cal_time_as_timet_with_zone (tt, e_cal_model_get_timezone (E_CAL_MODEL
(model)));
} else {
/* we assume that COMPLETED is entered in the current timezone,
@@ -533,7 +533,7 @@ set_geo (ECalModelComponent *comp_data,
{
gdouble latitude = 0.0, longitude = 0.0;
gint matched;
- ICalGeoType *geo;
+ ICalGeo *geo;
ICalProperty *prop;
prop = i_cal_component_get_first_property (comp_data->icalcomp, I_CAL_GEO_PROPERTY);
@@ -548,7 +548,7 @@ set_geo (ECalModelComponent *comp_data,
if (matched != 2)
show_geo_warning ();
- geo = i_cal_geo_type_new (latitude, longitude);
+ geo = i_cal_geo_new (latitude, longitude);
if (prop) {
i_cal_property_set_geo (prop, geo);
diff --git a/src/calendar/gui/e-cal-model.c b/src/calendar/gui/e-cal-model.c
index 5da5055c49..33ccf573f0 100644
--- a/src/calendar/gui/e-cal-model.c
+++ b/src/calendar/gui/e-cal-model.c
@@ -339,7 +339,7 @@ get_dtstart (ECalModel *model,
ECalModelComponent *comp_data)
{
ECalModelPrivate *priv;
- ICalTimetype *tt_start;
+ ICalTime *tt_start;
priv = model->priv;
@@ -387,14 +387,14 @@ static ECellDateEditValue *
get_datetime_from_utc (ECalModel *model,
ECalModelComponent *comp_data,
ICalPropertyKind propkind,
- ICalTimetype * (*get_value) (ICalProperty *prop),
+ ICalTime * (*get_value) (ICalProperty *prop),
ECellDateEditValue **buffer)
{
g_return_val_if_fail (buffer != NULL, NULL);
if (!*buffer) {
ECalModelPrivate *priv;
- ICalTimetype *tt_value;
+ ICalTime *tt_value;
ICalProperty *prop;
priv = model->priv;
@@ -567,7 +567,7 @@ set_summary (ECalModelComponent *comp_data,
static void
datetime_to_zone (ECalClient *client,
- ICalTimetype *tt,
+ ICalTime *tt,
ICalTimezone *tt_zone,
const gchar *tzid)
{
@@ -1440,7 +1440,7 @@ cal_model_create_component_from_values_thread (EAlertSinkThreadJobData *job_data
if (tt > 0) {
/* Store Memo DTSTART as date, not as date-time */
- ICalTimetype *itt = i_cal_time_from_timet_with_zone (tt,
+ ICalTime *itt = i_cal_time_from_timet_with_zone (tt,
i_cal_component_isa (comp_data->icalcomp) ==
I_CAL_VJOURNAL_COMPONENT, e_cal_model_get_timezone (ccd->model));
prop = i_cal_component_get_first_property (comp_data->icalcomp,
I_CAL_DTSTART_PROPERTY);
@@ -2624,14 +2624,14 @@ e_cal_model_update_comp_time (ECalModel *model,
gconstpointer time_value,
ICalPropertyKind kind,
void (*set_func) (ICalProperty *prop,
- ICalTimetype *v),
- ICalProperty * (*new_func) (ICalTimetype *v))
+ ICalTime *v),
+ ICalProperty * (*new_func) (ICalTime *v))
{
ECellDateEditValue *dv = (ECellDateEditValue *) time_value;
ICalProperty *prop;
ICalParameter *param;
ICalTimezone *model_zone;
- ICalTimetype *tt;
+ ICalTime *tt;
g_return_if_fail (model != NULL);
g_return_if_fail (comp_data != NULL);
@@ -3991,7 +3991,7 @@ e_cal_model_date_value_to_string (ECalModel *model,
return g_strdup ("");
/* We currently convert all the dates to the current timezone. */
- tmp_tm = icaltimetype_to_tm_with_zone (e_cell_date_edit_value_get_time (dv),
e_cell_date_edit_value_get_zone (dv), priv->zone);
+ tmp_tm = e_cal_util_i_cal_time_to_tm_with_zone (e_cell_date_edit_value_get_time (dv),
e_cell_date_edit_value_get_zone (dv), priv->zone);
memset (buffer, 0, sizeof (buffer));
e_time_format_date_and_time (&tmp_tm, priv->use_24_hour_format,
@@ -4009,14 +4009,14 @@ typedef struct _GenerateInstacesData {
static gboolean
ecm_generate_instances_cb (ICalComponent *comp,
- ICalTimetype *instance_start,
- ICalTimetype *instance_end,
+ ICalTime *instance_start,
+ ICalTime *instance_end,
gpointer user_data,
GCancellable *cancellable,
GError **error)
{
GenerateInstancesData *gid = user_data;
- ICalTimetype *changed_instance_start = NULL, *changed_instance_end = NULL;
+ ICalTime *changed_instance_start = NULL, *changed_instance_end = NULL;
gboolean res;
g_return_val_if_fail (gid != NULL, FALSE);
@@ -4084,10 +4084,10 @@ void
e_cal_model_set_instance_times (ECalModelComponent *comp_data,
const ICalTimezone *zone)
{
- ICalTimetype *instance_start = NULL, *instance_end = NULL;
+ ICalTime *instance_start = NULL, *instance_end = NULL;
if (i_cal_component_isa (comp_data->icalcomp) == I_CAL_VEVENT_COMPONENT) {
- ICalTimetype *start_time, *end_time;
+ ICalTime *start_time, *end_time;
start_time = i_cal_component_get_dtstart (comp_data->icalcomp);
end_time = i_cal_component_get_dtend (comp_data->icalcomp);
@@ -4097,7 +4097,7 @@ e_cal_model_set_instance_times (ECalModelComponent *comp_data,
* just make start_time = end_time so that end_time
* will be a valid date
*/
- end_time = i_cal_timetype_new_clone (start_time);
+ end_time = i_cal_time_new_clone (start_time);
i_cal_time_adjust (end_time, 1, 0, 0, 0);
i_cal_component_set_dtend (comp_data->icalcomp, end_time);
} else if (i_cal_time_is_date (start_time) && i_cal_time_is_date (end_time) &&
diff --git a/src/calendar/gui/e-cal-model.h b/src/calendar/gui/e-cal-model.h
index dbbdc76fdb..39219bdd5c 100644
--- a/src/calendar/gui/e-cal-model.h
+++ b/src/calendar/gui/e-cal-model.h
@@ -388,8 +388,8 @@ void e_cal_model_update_comp_time (ECalModel *model,
gconstpointer time_value,
ICalPropertyKind kind,
void (*set_func) (ICalProperty *prop,
- ICalTimetype *v),
- ICalProperty * (*new_func) (ICalTimetype *v));
+ ICalTime *v),
+ ICalProperty * (*new_func) (ICalTime *v));
void e_cal_model_emit_object_created (ECalModel *model,
ECalClient *where);
diff --git a/src/calendar/gui/e-calendar-view.c b/src/calendar/gui/e-calendar-view.c
index 2eb358388c..97c8946053 100644
--- a/src/calendar/gui/e-calendar-view.c
+++ b/src/calendar/gui/e-calendar-view.c
@@ -216,7 +216,7 @@ calendar_view_delete_event (ECalendarView *cal_view,
ECalComponentDateTime *dtstart;
dtstart = e_cal_component_get_dtstart (comp);
- i_cal_timetype_set_is_date (e_cal_component_datetime_get_value (dtstart), 1);
+ i_cal_time_set_is_date (e_cal_component_datetime_get_value (dtstart), 1);
/* set the recurrence ID of the object we send */
range = e_cal_component_range_new_take (E_CAL_COMPONENT_RANGE_SINGLE,
dtstart);
@@ -241,7 +241,7 @@ calendar_view_delete_event (ECalendarView *cal_view,
if (e_cal_component_is_instance (comp)) {
e_cal_ops_remove_component (model, event->comp_data->client, uid, rid,
E_CAL_OBJ_MOD_THIS, FALSE);
} else {
- ICalTimetype *instance_rid;
+ ICalTime *instance_rid;
ICalTimezone *zone = NULL;
ECalComponentDateTime *dt;
@@ -690,8 +690,8 @@ e_calendar_view_add_event_sync (ECalModel *model,
GtkWidget *top_level)
{
ECalComponent *comp;
- ICalTimetype *itime, *btime, *old_dtstart, *old_dtend;
- ICalDurationType *ic_dur, *ic_oneday;
+ ICalTime *itime, *btime, *old_dtstart, *old_dtend;
+ ICalDuration *ic_dur, *ic_oneday;
ICalTimezone *old_dtstart_zone;
time_t tt_start, tt_end, new_dtstart = 0;
gchar *uid;
@@ -705,16 +705,16 @@ e_calendar_view_add_event_sync (ECalModel *model,
tt_start = i_cal_time_as_timet (old_dtstart);
old_dtend = i_cal_component_get_dtend (icomp);
tt_end = i_cal_time_as_timet (old_dtend);
- ic_dur = i_cal_duration_type_from_int (tt_end - tt_start);
+ ic_dur = i_cal_duration_from_int (tt_end - tt_start);
- if (i_cal_duration_type_as_int (ic_dur) > 60 * 60 * 24) {
+ if (i_cal_duration_as_int (ic_dur) > 60 * 60 * 24) {
/* This is a long event */
- start_offset = i_cal_timetype_get_hour (old_dtstart) * 60 + i_cal_timetype_get_minute
(old_dtstart);
- end_offset = i_cal_timetype_get_hour (old_dtstart) * 60 + i_cal_timetype_get_minute
(old_dtend);
+ start_offset = i_cal_time_get_hour (old_dtstart) * 60 + i_cal_time_get_minute (old_dtstart);
+ end_offset = i_cal_time_get_hour (old_dtstart) * 60 + i_cal_time_get_minute (old_dtend);
}
- ic_oneday = i_cal_duration_type_null_duration ();
- i_cal_duration_type_set_days (ic_oneday, 1);
+ ic_oneday = i_cal_duration_null_duration ();
+ i_cal_duration_set_days (ic_oneday, 1);
old_dtstart_zone = i_cal_time_get_timezone (old_dtstart);
if (!old_dtstart_zone)
@@ -727,10 +727,10 @@ e_calendar_view_add_event_sync (ECalModel *model,
if (all_day_event) {
g_clear_object (&ic_dur);
ic_dur = g_object_ref (ic_oneday);
- } else if (i_cal_duration_type_as_int (ic_dur) >= 60 * 60 * 24 && !all_day) {
+ } else if (i_cal_duration_as_int (ic_dur) >= 60 * 60 * 24 && !all_day) {
g_clear_object (&ic_dur);
/* copy & paste from top canvas to main canvas */
- ic_dur = i_cal_duration_type_from_int (time_division * 60);
+ ic_dur = i_cal_duration_from_int (time_division * 60);
}
if (all_day)
@@ -739,15 +739,15 @@ e_calendar_view_add_event_sync (ECalModel *model,
new_dtstart = dtstart;
} else {
if (i_cal_time_is_date (old_dtstart) && i_cal_time_is_date (old_dtend) &&
- i_cal_duration_type_as_int (ic_dur) == i_cal_duration_type_as_int (ic_oneday)) {
+ i_cal_duration_as_int (ic_dur) == i_cal_duration_as_int (ic_oneday)) {
all_day_event = TRUE;
new_dtstart = dtstart;
} else {
- ICalTimetype *new_time = i_cal_time_from_timet_with_zone (dtstart, FALSE,
default_zone);
+ ICalTime *new_time = i_cal_time_from_timet_with_zone (dtstart, FALSE, default_zone);
- i_cal_timetype_set_hour (new_time, i_cal_timetype_get_hour (old_dtstart));
- i_cal_timetype_set_minute (new_time, i_cal_timetype_get_minute (old_dtstart));
- i_cal_timetype_set_second (new_time, i_cal_timetype_get_second (old_dtstart));
+ i_cal_time_set_hour (new_time, i_cal_time_get_hour (old_dtstart));
+ i_cal_time_set_minute (new_time, i_cal_time_get_minute (old_dtstart));
+ i_cal_time_set_second (new_time, i_cal_time_get_second (old_dtstart));
new_dtstart = i_cal_time_as_timet_with_zone (new_time, old_dtstart_zone);
@@ -759,13 +759,13 @@ e_calendar_view_add_event_sync (ECalModel *model,
/* set the timezone properly */
i_cal_time_set_timezone (itime, old_dtstart_zone);
if (all_day_event)
- i_cal_timetype_set_is_date (itime, TRUE);
+ i_cal_time_set_is_date (itime, TRUE);
i_cal_component_set_dtstart (icomp, itime);
- i_cal_timetype_set_is_date (itime, FALSE);
+ i_cal_time_set_is_date (itime, FALSE);
btime = i_cal_time_add (itime, ic_dur);
if (all_day_event)
- i_cal_timetype_set_is_date (itime, TRUE);
+ i_cal_time_set_is_date (itime, TRUE);
i_cal_component_set_dtend (icomp, itime);
g_clear_object (&itime);
@@ -1728,13 +1728,13 @@ tooltip_key_event (GtkWidget *tooltip,
}
static gchar *
-get_label (ICalTimetype *tt,
+get_label (ICalTime *tt,
ICalTimezone *f_zone,
ICalTimezone *t_zone)
{
struct tm tmp_tm;
- tmp_tm = icaltimetype_to_tm_with_zone (tt, f_zone, t_zone);
+ tmp_tm = e_cal_util_i_cal_time_to_tm_with_zone (tt, f_zone, t_zone);
return e_datetime_format_format_tm ("calendar", "table", i_cal_time_is_date (tt) ? DTFormatKindDate :
DTFormatKindDateTime, &tmp_tm);
}
@@ -2126,7 +2126,7 @@ e_calendar_view_dup_component_summary (ICalComponent *icomp)
since_year_str = e_cal_util_component_dup_x_property (icomp, "X-EVOLUTION-SINCE-YEAR");
if (since_year_str) {
- ICalTimetype *dtstart;
+ ICalTime *dtstart;
gint since_year;
gchar *res = NULL;
@@ -2135,12 +2135,12 @@ e_calendar_view_dup_component_summary (ICalComponent *icomp)
dtstart = i_cal_component_get_dtstart (icomp);
if (since_year > 0 && dtstart && i_cal_time_is_valid_time (dtstart) &&
- i_cal_timetype_get_year (dtstart) - since_year > 0) {
+ i_cal_time_get_year (dtstart) - since_year > 0) {
/* Translators: the '%s' stands for a component summary, the '%d' for the
years.
The string is used for Birthday & Anniversary events where the first year
is
know, constructing a summary which also shows how many years the birthday
or
anniversary is for. Example: "Birthday: John Doe (13)" */
- summary = g_strdup_printf (C_("BirthdaySummary", "%s (%d)"), summary ?
summary : "", i_cal_timetype_get_year (dtstart) - since_year);
+ summary = g_strdup_printf (C_("BirthdaySummary", "%s (%d)"), summary ?
summary : "", i_cal_time_get_year (dtstart) - since_year);
}
g_clear_object (&dtstart);
@@ -2313,7 +2313,7 @@ e_calendar_view_get_description_text (ECalendarView *cal_view)
{
time_t start_time, end_time;
struct tm start_tm, end_tm;
- ICalTimetype *tt;
+ ICalTime *tt;
ICalTimezone *zone;
gchar start_buffer[512] = { 0 };
gchar end_buffer[512] = { 0 };
@@ -2326,12 +2326,12 @@ e_calendar_view_get_description_text (ECalendarView *cal_view)
zone = e_cal_model_get_timezone (cal_view->priv->model);
tt = i_cal_time_from_timet_with_zone (start_time, FALSE, zone);
- start_tm = icaltimetype_to_tm (tt);
+ start_tm = e_cal_util_i_cal_time_to_tm (tt);
g_clear_object (&tt);
/* Subtract one from end_time so we don't get an extra day. */
tt = i_cal_time_from_timet_with_zone (end_time - 1, FALSE, zone);
- end_tm = icaltimetype_to_tm (tt);
+ end_tm = e_cal_util_i_cal_time_to_tm (tt);
g_clear_object (&tt);
if (E_IS_MONTH_VIEW (cal_view) || E_IS_CAL_LIST_VIEW (cal_view)) {
diff --git a/src/calendar/gui/e-cell-date-edit-text.c b/src/calendar/gui/e-cell-date-edit-text.c
index 98b7ff8dd0..0fd8c73e9c 100644
--- a/src/calendar/gui/e-cell-date-edit-text.c
+++ b/src/calendar/gui/e-cell-date-edit-text.c
@@ -123,7 +123,7 @@ cell_date_edit_text_get_text (ECellText *cell,
ECellDateEditText *ecd = E_CELL_DATE_EDIT_TEXT (cell);
ECellDateEditValue *dv = e_table_model_value_at (model, col, row);
ICalTimezone *timezone;
- ICalTimetype *tt;
+ ICalTime *tt;
struct tm tmp_tm;
gchar *res;
@@ -138,7 +138,7 @@ cell_date_edit_text_get_text (ECellText *cell,
* timezone, we convert it to the current timezone to display
* it in the table. If the user actually edits the value,
* it will be set to the current timezone. See set_value (). */
- tmp_tm = icaltimetype_to_tm_with_zone (tt, e_cell_date_edit_value_get_zone (dv), timezone);
+ tmp_tm = e_cal_util_i_cal_time_to_tm_with_zone (tt, e_cell_date_edit_value_get_zone (dv), timezone);
res = e_datetime_format_format_tm (
"calendar", "table", i_cal_time_is_date (tt) ?
@@ -221,10 +221,10 @@ cell_date_edit_text_set_value (ECellText *cell,
if (status == E_TIME_PARSE_NONE) {
value = NULL;
} else {
- ICalTimetype *tt;
+ ICalTime *tt;
ICalTimezone *zone;
- tt = tm_to_icaltimetype (&tmp_tm, is_date);
+ tt = e_cal_util_tm_to_i_cal_time (&tmp_tm, is_date);
if (is_date) {
zone = NULL;
@@ -364,7 +364,7 @@ e_cell_date_edit_compare_cb (gconstpointer a,
{
ECellDateEditValue *dv1 = (ECellDateEditValue *) a;
ECellDateEditValue *dv2 = (ECellDateEditValue *) b;
- ICalTimetype *tt;
+ ICalTime *tt;
gint res;
/* First check if either is NULL. NULL dates sort last. */
@@ -378,7 +378,7 @@ e_cell_date_edit_compare_cb (gconstpointer a,
}
/* Copy the 2nd value and convert it to the same timezone as the first. */
- tt = i_cal_timetype_new_clone (e_cell_date_edit_value_get_time (dv2));
+ tt = i_cal_time_new_clone (e_cell_date_edit_value_get_time (dv2));
i_cal_timezone_convert_time (tt, e_cell_date_edit_value_get_zone (dv2),
e_cell_date_edit_value_get_zone (dv1));
/* Now we can compare them. */
@@ -390,29 +390,29 @@ e_cell_date_edit_compare_cb (gconstpointer a,
}
struct _ECellDateEditValue {
- ICalTimetype *tt;
+ ICalTime *tt;
ICalTimezone *zone;
};
ECellDateEditValue *
-e_cell_date_edit_value_new (const ICalTimetype *tt,
+e_cell_date_edit_value_new (const ICalTime *tt,
const ICalTimezone *zone)
{
- g_return_val_if_fail (I_CAL_IS_TIMETYPE (tt), NULL);
+ g_return_val_if_fail (I_CAL_IS_TIME (tt), NULL);
if (zone)
g_return_val_if_fail (I_CAL_IS_TIMEZONE (zone), NULL);
- return e_cell_date_edit_value_new_take (i_cal_timetype_new_clone (tt),
+ return e_cell_date_edit_value_new_take (i_cal_time_new_clone (tt),
zone ? e_cal_util_copy_timezone (zone) : NULL);
}
ECellDateEditValue *
-e_cell_date_edit_value_new_take (ICalTimetype *tt,
+e_cell_date_edit_value_new_take (ICalTime *tt,
ICalTimezone *zone)
{
ECellDateEditValue *value;
- g_return_val_if_fail (I_CAL_IS_TIMETYPE (tt), NULL);
+ g_return_val_if_fail (I_CAL_IS_TIME (tt), NULL);
if (zone)
g_return_val_if_fail (I_CAL_IS_TIMEZONE (zone), NULL);
@@ -442,7 +442,7 @@ e_cell_date_edit_value_free (ECellDateEditValue *value)
}
}
-ICalTimetype *
+ICalTime *
e_cell_date_edit_value_get_time (const ECellDateEditValue *value)
{
g_return_val_if_fail (value != NULL, NULL);
@@ -452,20 +452,20 @@ e_cell_date_edit_value_get_time (const ECellDateEditValue *value)
void
e_cell_date_edit_value_set_time (ECellDateEditValue *value,
- const ICalTimetype *tt)
+ const ICalTime *tt)
{
g_return_if_fail (value != NULL);
- g_return_if_fail (I_CAL_IS_TIMETYPE (tt));
+ g_return_if_fail (I_CAL_IS_TIME (tt));
- e_cell_date_edit_value_take_time (value, i_cal_timetype_new_clone (tt));
+ e_cell_date_edit_value_take_time (value, i_cal_time_new_clone (tt));
}
void
e_cell_date_edit_value_take_time (ECellDateEditValue *value,
- ICalTimetype *tt)
+ ICalTime *tt)
{
g_return_if_fail (value != NULL);
- g_return_if_fail (I_CAL_IS_TIMETYPE (tt));
+ g_return_if_fail (I_CAL_IS_TIME (tt));
if (value->tt != tt) {
g_clear_object (&value->tt);
diff --git a/src/calendar/gui/e-cell-date-edit-text.h b/src/calendar/gui/e-cell-date-edit-text.h
index 5c13f0a7b5..e0e043a97e 100644
--- a/src/calendar/gui/e-cell-date-edit-text.h
+++ b/src/calendar/gui/e-cell-date-edit-text.h
@@ -50,19 +50,19 @@ G_BEGIN_DECLS
typedef struct _ECellDateEditValue ECellDateEditValue;
ECellDateEditValue *
- e_cell_date_edit_value_new (const ICalTimetype *tt,
+ e_cell_date_edit_value_new (const ICalTime *tt,
const ICalTimezone *zone);
ECellDateEditValue *
- e_cell_date_edit_value_new_take (ICalTimetype *tt,
+ e_cell_date_edit_value_new_take (ICalTime *tt,
ICalTimezone *zone);
ECellDateEditValue *
e_cell_date_edit_value_copy (const ECellDateEditValue *src);
void e_cell_date_edit_value_free (ECellDateEditValue *value);
-ICalTimetype * e_cell_date_edit_value_get_time (const ECellDateEditValue *value);
+ICalTime * e_cell_date_edit_value_get_time (const ECellDateEditValue *value);
void e_cell_date_edit_value_set_time (ECellDateEditValue *value,
- const ICalTimetype *tt);
+ const ICalTime *tt);
void e_cell_date_edit_value_take_time(ECellDateEditValue *value,
- ICalTimetype *tt);
+ ICalTime *tt);
ICalTimezone * e_cell_date_edit_value_get_zone (const ECellDateEditValue *value);
void e_cell_date_edit_value_set_zone (ECellDateEditValue *value,
const ICalTimezone *zone);
diff --git a/src/calendar/gui/e-comp-editor-page-recurrence.c
b/src/calendar/gui/e-comp-editor-page-recurrence.c
index e72aff0749..1b40dc720d 100644
--- a/src/calendar/gui/e-comp-editor-page-recurrence.c
+++ b/src/calendar/gui/e-comp-editor-page-recurrence.c
@@ -440,7 +440,7 @@ ecep_recurrence_get_current_time_cb (ECalendarItem *calitem,
today = icaltime_today ();
- return icaltimetype_to_tm (&today);
+ return e_cal_util_i_cal_time_to_tm (&today);
}
static GtkWidget *
diff --git a/src/calendar/gui/e-comp-editor-property-part.h b/src/calendar/gui/e-comp-editor-property-part.h
index 6df0c132b9..6c26560dea 100644
--- a/src/calendar/gui/e-comp-editor-property-part.h
+++ b/src/calendar/gui/e-comp-editor-property-part.h
@@ -247,10 +247,10 @@ struct _ECompEditorPropertyPartDatetimeClass {
/* ICal property kind and its manipulation functions */
ICalPropertyKind prop_kind;
- ICalProperty * (* i_cal_new_func) (ICalTimetype *value);
+ ICalProperty * (* i_cal_new_func) (ICalTime *value);
void (* i_cal_set_func) (ICalProperty *prop,
- ICalTimetype *value);
- ICalTimetype * (* i_cal_get_func) (const ICalProperty *prop);
+ ICalTime *value);
+ ICalTime * (* i_cal_get_func) (const ICalProperty *prop);
};
GType e_comp_editor_property_part_datetime_get_type (void) G_GNUC_CONST;
@@ -268,8 +268,8 @@ void e_comp_editor_property_part_datetime_set_allow_no_date_set
gboolean e_comp_editor_property_part_datetime_get_allow_no_date_set
(ECompEditorPropertyPartDatetime
*part_datetime);
void e_comp_editor_property_part_datetime_set_value (ECompEditorPropertyPartDatetime
*part_datetime,
- const ICalTimetype *value);
-ICalTimetype * e_comp_editor_property_part_datetime_get_value (ECompEditorPropertyPartDatetime
*part_datetime);
+ const ICalTime *value);
+ICalTime * e_comp_editor_property_part_datetime_get_value (ECompEditorPropertyPartDatetime
*part_datetime);
gboolean e_comp_editor_property_part_datetime_check_validity
(ECompEditorPropertyPartDatetime
*part_datetime,
gboolean *out_date_is_valid,
diff --git a/src/calendar/gui/e-date-time-list.c b/src/calendar/gui/e-date-time-list.c
index be469b1907..719c25a1ab 100644
--- a/src/calendar/gui/e-date-time-list.c
+++ b/src/calendar/gui/e-date-time-list.c
@@ -64,10 +64,10 @@ G_DEFINE_TYPE_WITH_CODE (
GTK_TYPE_TREE_MODEL, e_date_time_list_tree_model_init))
static gint
-compare_datetime (const ICalTimetype *itt1,
- const ICalTimetype *itt2)
+compare_datetime (const ICalTime *itt1,
+ const ICalTime *itt2)
{
- return i_cal_time_compare ((ICalTimetype *) itt1, (ICalTimetype *) itt2);
+ return i_cal_time_compare ((ICalTime *) itt1, (ICalTime *) itt2);
}
static void
@@ -138,11 +138,11 @@ row_updated (EDateTimeList *date_time_list,
/* Builds a static string out of an exception date */
static gchar *
get_exception_string (EDateTimeList *date_time_list,
- ICalTimetype *itt)
+ ICalTime *itt)
{
static gchar buf[256];
struct tm tmp_tm;
- ICalTimetype *tt;
+ ICalTime *tt;
ICalTimezone *zone;
gboolean use_24_hour_format;
@@ -154,7 +154,7 @@ get_exception_string (EDateTimeList *date_time_list,
else
tt = g_object_ref (itt);
- tmp_tm = icaltimetype_to_tm (tt);
+ tmp_tm = e_cal_util_i_cal_time_to_tm (tt);
e_time_format_date_and_time (
&tmp_tm, use_24_hour_format,
@@ -312,7 +312,7 @@ date_time_list_get_value (GtkTreeModel *tree_model,
GValue *value)
{
EDateTimeList *date_time_list = E_DATE_TIME_LIST (tree_model);
- ICalTimetype *itt;
+ ICalTime *itt;
GList *link;
const gchar *str;
@@ -510,7 +510,7 @@ e_date_time_list_new (void)
return g_object_new (E_TYPE_DATE_TIME_LIST, NULL);
}
-ICalTimetype *
+ICalTime *
e_date_time_list_get_date_time (EDateTimeList *date_time_list,
GtkTreeIter *iter)
{
@@ -522,15 +522,15 @@ e_date_time_list_get_date_time (EDateTimeList *date_time_list,
void
e_date_time_list_set_date_time (EDateTimeList *date_time_list,
GtkTreeIter *iter,
- const ICalTimetype *itt)
+ const ICalTime *itt)
{
- ICalTimetype *itt_old;
+ ICalTime *itt_old;
g_return_if_fail (IS_VALID_ITER (date_time_list, iter));
itt_old = G_LIST (iter->user_data)->data;
g_clear_object (&itt_old);
- G_LIST (iter->user_data)->data = i_cal_timetype_new_clone (itt);
+ G_LIST (iter->user_data)->data = i_cal_time_new_clone (itt);
row_updated (date_time_list,
g_list_position (date_time_list->priv->list, G_LIST (iter->user_data)));
}
@@ -584,13 +584,13 @@ e_date_time_list_set_timezone (EDateTimeList *date_time_list,
void
e_date_time_list_append (EDateTimeList *date_time_list,
GtkTreeIter *iter,
- const ICalTimetype *itt)
+ const ICalTime *itt)
{
g_return_if_fail (itt != NULL);
- g_return_if_fail (i_cal_time_is_valid_time ((ICalTimetype *) itt));
+ g_return_if_fail (i_cal_time_is_valid_time ((ICalTime *) itt));
if (g_list_find_custom (date_time_list->priv->list, itt, (GCompareFunc) compare_datetime) == NULL) {
- date_time_list->priv->list = g_list_append (date_time_list->priv->list,
i_cal_timetype_new_clone (itt));
+ date_time_list->priv->list = g_list_append (date_time_list->priv->list, i_cal_time_new_clone
(itt));
row_added (date_time_list, g_list_length (date_time_list->priv->list) - 1);
}
@@ -604,7 +604,7 @@ void
e_date_time_list_remove (EDateTimeList *date_time_list,
GtkTreeIter *iter)
{
- ICalTimetype *itt;
+ ICalTime *itt;
gint n;
g_return_if_fail (IS_VALID_ITER (date_time_list, iter));
diff --git a/src/calendar/gui/e-date-time-list.h b/src/calendar/gui/e-date-time-list.h
index 1ac7490844..c9eea14ce5 100644
--- a/src/calendar/gui/e-date-time-list.h
+++ b/src/calendar/gui/e-date-time-list.h
@@ -70,11 +70,11 @@ struct _EDateTimeListClass {
GType e_date_time_list_get_type (void);
EDateTimeList * e_date_time_list_new (void);
-ICalTimetype * e_date_time_list_get_date_time (EDateTimeList *date_time_list,
+ICalTime * e_date_time_list_get_date_time (EDateTimeList *date_time_list,
GtkTreeIter *iter);
void e_date_time_list_set_date_time (EDateTimeList *date_time_list,
GtkTreeIter *iter,
- const ICalTimetype *itt);
+ const ICalTime *itt);
gboolean e_date_time_list_get_use_24_hour_format
(EDateTimeList *date_time_list);
void e_date_time_list_set_use_24_hour_format
@@ -85,7 +85,7 @@ void e_date_time_list_set_timezone (EDateTimeList *date_time_list,
const ICalTimezone *zone);
void e_date_time_list_append (EDateTimeList *date_time_list,
GtkTreeIter *iter,
- const ICalTimetype *itt);
+ const ICalTime *itt);
void e_date_time_list_remove (EDateTimeList *date_time_list,
GtkTreeIter *iter);
void e_date_time_list_clear (EDateTimeList *date_time_list);
diff --git a/src/calendar/gui/e-day-view-main-item.c b/src/calendar/gui/e-day-view-main-item.c
index 91f2f2a7f1..712f070773 100644
--- a/src/calendar/gui/e-day-view-main-item.c
+++ b/src/calendar/gui/e-day-view-main-item.c
@@ -1023,7 +1023,7 @@ day_view_main_item_draw (GnomeCanvasItem *canvas_item,
gint day_x, day_w;
gint start_row, end_row, rect_x, rect_y, rect_width, rect_height;
gint days_shown;
- ICalTimetype *day_start_tt, *today_tt;
+ ICalTime *day_start_tt, *today_tt;
gboolean today = FALSE;
cairo_region_t *draw_region;
GdkRectangle rect;
@@ -1264,7 +1264,7 @@ day_view_main_item_draw (GnomeCanvasItem *canvas_item,
if (e_day_view_marcus_bains_get_show_line (day_view)) {
ICalTimezone *zone;
- ICalTimetype *time_now, *day_start;
+ ICalTime *time_now, *day_start;
const gchar *marcus_bains_day_view_color;
gint marcus_bains_y;
GdkColor mb_color;
@@ -1291,7 +1291,7 @@ day_view_main_item_draw (GnomeCanvasItem *canvas_item,
if (i_cal_time_compare_date_only (day_start, time_now) == 0) {
grid_x1 = day_view->day_offsets[day] - x + E_DAY_VIEW_BAR_WIDTH;
grid_x2 = day_view->day_offsets[day + 1] - x - 1;
- marcus_bains_y = (i_cal_timetype_get_hour (time_now) * 60 +
i_cal_timetype_get_minute (time_now)) * day_view->row_height / time_divisions - y;
+ marcus_bains_y = (i_cal_time_get_hour (time_now) * 60 + i_cal_time_get_minute
(time_now)) * day_view->row_height / time_divisions - y;
cairo_set_line_width (cr, 1.5);
cairo_move_to (cr, grid_x1, marcus_bains_y);
cairo_line_to (cr, grid_x2, marcus_bains_y);
diff --git a/src/calendar/gui/e-day-view-time-item.c b/src/calendar/gui/e-day-view-time-item.c
index 0df2450c84..a7ced493fa 100644
--- a/src/calendar/gui/e-day-view-time-item.c
+++ b/src/calendar/gui/e-day-view-time-item.c
@@ -352,7 +352,7 @@ edvti_draw_zone (GnomeCanvasItem *canvas_item,
/* shift time with a difference between
* local time and the other timezone */
ICalTimezone *cal_zone;
- ICalTimetype *tt,*tt2;
+ ICalTime *tt;
gint diff;
struct tm mn;
@@ -368,18 +368,16 @@ edvti_draw_zone (GnomeCanvasItem *canvas_item,
g_clear_object (&tt);
tt = i_cal_time_from_timet_with_zone (day_view->day_starts[0], 0, cal_zone);
- i_cal_timetype_set_is_date (tt, FALSE);
+ i_cal_time_set_is_date (tt, FALSE);
i_cal_time_set_timezone (tt, cal_zone);
- tt2 = i_cal_time_convert_to_zone (tt, use_zone);
- g_object_unref (tt);
- tt = tt2;
+ i_cal_time_convert_to_zone_inplace (tt, use_zone);
if (diff != 0) {
/* shows the next midnight */
i_cal_time_adjust (tt, 1, 0, 0, 0);
}
- mn = icaltimetype_to_tm (tt);
+ mn = e_cal_util_i_cal_time_to_tm (tt);
g_clear_object (&tt);
@@ -418,7 +416,7 @@ edvti_draw_zone (GnomeCanvasItem *canvas_item,
/* Draw the Marcus Bains Line first, so it appears under other elements. */
if (e_day_view_marcus_bains_get_show_line (day_view)) {
- ICalTimetype *time_now;
+ ICalTime *time_now;
const gchar *marcus_bains_time_bar_color;
gint marcus_bains_y;
@@ -441,7 +439,7 @@ edvti_draw_zone (GnomeCanvasItem *canvas_item,
e_calendar_view_get_timezone (
E_CALENDAR_VIEW (day_view)));
marcus_bains_y =
- (i_cal_timetype_get_hour (time_now) * 60 + i_cal_timetype_get_minute (time_now)) *
+ (i_cal_time_get_hour (time_now) * 60 + i_cal_time_get_minute (time_now)) *
day_view->row_height / time_divisions - y;
cairo_set_line_width (cr, 1.5);
cairo_move_to (
diff --git a/src/calendar/gui/e-day-view-top-item.c b/src/calendar/gui/e-day-view-top-item.c
index 05017d0d80..bc3b0c99d4 100644
--- a/src/calendar/gui/e-day-view-top-item.c
+++ b/src/calendar/gui/e-day-view-top-item.c
@@ -831,7 +831,7 @@ e_day_view_top_item_get_day_label (EDayView *day_view,
gint buffer_len)
{
ECalendarView *view;
- ICalTimetype *day_start_tt;
+ ICalTime *day_start_tt;
ICalTimezone *zone;
struct tm day_start;
const gchar *format;
@@ -841,7 +841,7 @@ e_day_view_top_item_get_day_label (EDayView *day_view,
day_start_tt = i_cal_time_from_timet_with_zone (
day_view->day_starts[day], FALSE, zone);
- day_start = icaltimetype_to_tm (day_start_tt);
+ day_start = e_cal_util_i_cal_time_to_tm (day_start_tt);
g_clear_object (&day_start_tt);
if (day_view->date_format == E_DAY_VIEW_DATE_FULL)
diff --git a/src/calendar/gui/e-memo-table.c b/src/calendar/gui/e-memo-table.c
index c6082a397c..c9f85f41a7 100644
--- a/src/calendar/gui/e-memo-table.c
+++ b/src/calendar/gui/e-memo-table.c
@@ -120,7 +120,7 @@ memo_table_get_current_time (ECellDateEdit *ecde,
EMemoTable *memo_table = user_data;
ECalModel *model;
ICalTimezone *zone;
- ICalTimetype *tt;
+ ICalTime *tt;
struct tm tmp_tm;
/* Get the current timezone. */
@@ -130,7 +130,7 @@ memo_table_get_current_time (ECellDateEdit *ecde,
tt = i_cal_time_from_timet_with_zone (time (NULL), FALSE, zone);
/* Now copy it to the struct tm and return it. */
- tmp_tm = icaltimetype_to_tm (tt);
+ tmp_tm = e_cal_util_i_cal_time_to_tm (tt);
g_clear_object (&tt);
@@ -526,7 +526,7 @@ memo_table_query_tooltip (GtkWidget *widget,
if (dtstart && e_cal_component_datetime_get_value (dtstart)) {
gchar *str;
- tmp_tm = icaltimetype_to_tm_with_zone (e_cal_component_datetime_get_value (dtstart), zone,
default_zone);
+ tmp_tm = e_cal_util_i_cal_time_to_tm_with_zone (e_cal_component_datetime_get_value (dtstart),
zone, default_zone);
str = e_datetime_format_format_tm ("calendar", "table",
i_cal_time_is_date (e_cal_component_datetime_get_value (dtstart)) ? DTFormatKindDate
: DTFormatKindDateTime,
&tmp_tm);
@@ -543,7 +543,7 @@ memo_table_query_tooltip (GtkWidget *widget,
if (dtdue && e_cal_component_datetime_get_value (dtdue)) {
gchar *str;
- tmp_tm = icaltimetype_to_tm_with_zone (e_cal_component_datetime_get_value (dtdue), zone,
default_zone);
+ tmp_tm = e_cal_util_i_cal_time_to_tm_with_zone (e_cal_component_datetime_get_value (dtdue),
zone, default_zone);
str = e_datetime_format_format_tm ("calendar", "table",
i_cal_time_is_date (e_cal_component_datetime_get_value (dtdue)) ? DTFormatKindDate :
DTFormatKindDateTime,
&tmp_tm);
diff --git a/src/calendar/gui/e-send-options-utils.c b/src/calendar/gui/e-send-options-utils.c
index 713adb7076..bb3cc5157f 100644
--- a/src/calendar/gui/e-send-options-utils.c
+++ b/src/calendar/gui/e-send-options-utils.c
@@ -87,7 +87,7 @@ e_send_options_utils_set_default_data (ESendOptionsDialog *sod,
if (!strcmp (value, "none"))
gopts->delay_enabled = FALSE;
else {
- ICalTimetype *itt;
+ ICalTime *itt;
itt = i_cal_time_from_string (value);
@@ -224,7 +224,7 @@ e_send_options_utils_fill_component (ESendOptionsDialog *sod,
}
if (gopts->delay_enabled) {
- ICalTimetype *temp;
+ ICalTime *temp;
gchar *str;
temp = i_cal_time_from_timet_with_zone (gopts->delay_until, FALSE, zone);
diff --git a/src/calendar/gui/e-task-table.c b/src/calendar/gui/e-task-table.c
index 2ed3660873..029f9463b0 100644
--- a/src/calendar/gui/e-task-table.c
+++ b/src/calendar/gui/e-task-table.c
@@ -864,7 +864,7 @@ task_table_query_tooltip (GtkWidget *widget,
if (dtstart && e_cal_component_datetime_get_value (dtstart)) {
gchar *str;
- tmp_tm = icaltimetype_to_tm_with_zone (e_cal_component_datetime_get_value (dtstart), zone,
default_zone);
+ tmp_tm = e_cal_util_i_cal_time_to_tm_with_zone (e_cal_component_datetime_get_value (dtstart),
zone, default_zone);
str = e_datetime_format_format_tm ("calendar", "table",
i_cal_time_is_date (e_cal_component_datetime_get_value (dtstart)) ? DTFormatKindDate
: DTFormatKindDateTime,
&tmp_tm);
@@ -880,7 +880,7 @@ task_table_query_tooltip (GtkWidget *widget,
if (dtdue && e_cal_component_datetime_get_value (dtdue)) {
gchar *str;
- tmp_tm = icaltimetype_to_tm_with_zone (e_cal_component_datetime_get_value (dtdue), zone,
default_zone);
+ tmp_tm = e_cal_util_i_cal_time_to_tm_with_zone (e_cal_component_datetime_get_value (dtdue),
zone, default_zone);
str = e_datetime_format_format_tm ("calendar", "table",
i_cal_time_is_date (e_cal_component_datetime_get_value (dtdue)) ? DTFormatKindDate :
DTFormatKindDateTime,
&tmp_tm);
@@ -1812,7 +1812,7 @@ e_task_table_get_current_time (ECellDateEdit *ecde,
ETaskTable *task_table = data;
ECalModel *model;
ICalTimezone *zone;
- ICalTimetype *tt;
+ ICalTime *tt;
struct tm tmp_tm;
/* Get the current timezone. */
@@ -1821,7 +1821,7 @@ e_task_table_get_current_time (ECellDateEdit *ecde,
tt = i_cal_time_from_timet_with_zone (time (NULL), FALSE, zone);
- tmp_tm = icaltimetype_to_tm (tt);
+ tmp_tm = e_cal_util_i_cal_time_to_tm (tt);
g_clear_object (&tt);
diff --git a/src/calendar/gui/e-to-do-pane.c b/src/calendar/gui/e-to-do-pane.c
index fab57667d8..fe0f783317 100644
--- a/src/calendar/gui/e-to-do-pane.c
+++ b/src/calendar/gui/e-to-do-pane.c
@@ -170,18 +170,18 @@ etdp_free_component_refs (gpointer ptr)
}
static guint
-etdp_create_date_mark (/* const */ ICalTimetype *itt)
+etdp_create_date_mark (/* const */ ICalTime *itt)
{
if (!itt)
return 0;
- return i_cal_timetype_get_year (itt) * 10000 +
- i_cal_timetype_get_month (itt) * 100 +
- i_cal_timetype_get_day (itt);
+ return i_cal_time_get_year (itt) * 10000 +
+ i_cal_time_get_month (itt) * 100 +
+ i_cal_time_get_day (itt);
}
static void
-etdp_itt_to_zone (ICalTimetype *itt,
+etdp_itt_to_zone (ICalTime *itt,
const gchar *itt_tzid,
ECalClient *client,
ICalTimezone *default_zone)
@@ -208,7 +208,7 @@ etdp_date_time_to_string (const ECalComponentDateTime *dt,
guint today_date_mark,
gboolean is_task,
gboolean use_24hour_format,
- ICalTimetype **out_itt)
+ ICalTime **out_itt)
{
gboolean is_overdue;
gchar *res;
@@ -217,7 +217,7 @@ etdp_date_time_to_string (const ECalComponentDateTime *dt,
g_return_val_if_fail (e_cal_component_datetime_get_value (dt) != NULL, NULL);
g_return_val_if_fail (out_itt != NULL, NULL);
- *out_itt = i_cal_timetype_new_clone (e_cal_component_datetime_get_value (dt));
+ *out_itt = i_cal_time_new_clone (e_cal_component_datetime_get_value (dt));
etdp_itt_to_zone (*out_itt, e_cal_component_datetime_get_tzid (dt), client, default_zone);
@@ -229,14 +229,14 @@ etdp_date_time_to_string (const ECalComponentDateTime *dt,
if (is_overdue) {
struct tm tm;
- tm = icaltimetype_to_tm (*out_itt);
+ tm = e_cal_util_i_cal_time_to_tm (*out_itt);
res = e_datetime_format_format_tm ("calendar", "table", i_cal_time_is_date (*out_itt) ?
DTFormatKindDate : DTFormatKindDateTime, &tm);
} else {
if (use_24hour_format) {
- res = g_strdup_printf ("%d:%02d", i_cal_timetype_get_hour (*out_itt),
i_cal_timetype_get_minute (*out_itt));
+ res = g_strdup_printf ("%d:%02d", i_cal_time_get_hour (*out_itt),
i_cal_time_get_minute (*out_itt));
} else {
- gint hour = i_cal_timetype_get_hour (*out_itt);
+ gint hour = i_cal_time_get_hour (*out_itt);
const gchar *suffix;
if (hour < 12) {
@@ -251,10 +251,10 @@ etdp_date_time_to_string (const ECalComponentDateTime *dt,
if (hour == 0)
hour = 12;
- if (!i_cal_timetype_get_minute (*out_itt))
+ if (!i_cal_time_get_minute (*out_itt))
res = g_strdup_printf ("%d %s", hour, suffix);
else
- res = g_strdup_printf ("%d:%02d %s", hour, i_cal_timetype_get_minute
(*out_itt), suffix);
+ res = g_strdup_printf ("%d:%02d %s", hour, i_cal_time_get_minute (*out_itt),
suffix);
}
}
@@ -283,21 +283,21 @@ etdp_append_to_string_escaped (GString *str,
static gchar *
etdp_format_date_time (ECalClient *client,
ICalTimezone *default_zone,
- const ICalTimetype *in_itt,
+ const ICalTime *in_itt,
const gchar *tzid)
{
- ICalTimetype *itt;
+ ICalTime *itt;
struct tm tm;
gchar *res;
if (!in_itt)
return NULL;
- itt = i_cal_timetype_new_clone ((ICalTimetype *) in_itt);
+ itt = i_cal_time_new_clone ((ICalTime *) in_itt);
etdp_itt_to_zone (itt, tzid, client, default_zone);
- tm = icaltimetype_to_tm (itt);
+ tm = e_cal_util_i_cal_time_to_tm (itt);
res = e_datetime_format_format_tm ("calendar", "table", i_cal_time_is_date (itt) ? DTFormatKindDate :
DTFormatKindDateTime, &tm);
@@ -338,7 +338,7 @@ etdp_get_component_data (EToDoPane *to_do_pane,
ICalComponent *icomp;
ECalComponentDateTime *dt;
ECalComponentId *id;
- ICalTimetype *itt = NULL;
+ ICalTime *itt = NULL;
const gchar *prefix, *location, *description, *uid_str, *rid_str;
gboolean task_has_due_date = TRUE, is_cancelled = FALSE; /* ignored for events, thus like being set */
ICalPropertyStatus status;
@@ -382,7 +382,7 @@ etdp_get_component_data (EToDoPane *to_do_pane,
if (*out_is_task) {
ECalComponentDateTime *dtstart;
- ICalTimetype *completed;
+ ICalTime *completed;
/* Tasks after events */
prefix = "1";
@@ -406,7 +406,7 @@ etdp_get_component_data (EToDoPane *to_do_pane,
if (!dt || !e_cal_component_datetime_get_value (dt)) {
/* Fill the itt structure in case the task has no Due date */
- itt = i_cal_timetype_new_clone (e_cal_component_datetime_get_value (dtstart));
+ itt = i_cal_time_new_clone (e_cal_component_datetime_get_value (dtstart));
etdp_itt_to_zone (itt, e_cal_component_datetime_get_tzid (dtstart), client,
default_zone);
}
}
@@ -454,16 +454,16 @@ etdp_get_component_data (EToDoPane *to_do_pane,
if (dt && e_cal_component_datetime_get_value (dt)) {
ECalComponentDateTime *dtend;
- ICalTimetype *ittstart, *ittend;
+ ICalTime *ittstart, *ittend;
gchar *strstart, *strduration;
dtend = e_cal_component_get_dtend (comp);
- ittstart = i_cal_timetype_new_clone (e_cal_component_datetime_get_value (dt));
+ ittstart = i_cal_time_new_clone (e_cal_component_datetime_get_value (dt));
if (dtend && e_cal_component_datetime_get_value (dtend))
- ittend = i_cal_timetype_new_clone (e_cal_component_datetime_get_value
(dtend));
+ ittend = i_cal_time_new_clone (e_cal_component_datetime_get_value (dtend));
else
- ittend = i_cal_timetype_new_clone (ittstart);
+ ittend = i_cal_time_new_clone (ittstart);
etdp_itt_to_zone (ittstart, e_cal_component_datetime_get_tzid (dt), client,
default_zone);
etdp_itt_to_zone (ittend, (dtend && e_cal_component_datetime_get_value (dtend)) ?
@@ -540,23 +540,23 @@ etdp_get_component_data (EToDoPane *to_do_pane,
} else {
*out_sort_key = g_strdup_printf ("%s-%04d%02d%02d%02d%02d%02d-%s-%s-%s",
prefix,
- i_cal_timetype_get_year (itt),
- i_cal_timetype_get_month (itt),
- i_cal_timetype_get_day (itt),
- i_cal_timetype_get_hour (itt),
- i_cal_timetype_get_minute (itt),
- i_cal_timetype_get_second (itt),
+ i_cal_time_get_year (itt),
+ i_cal_time_get_month (itt),
+ i_cal_time_get_day (itt),
+ i_cal_time_get_hour (itt),
+ i_cal_time_get_minute (itt),
+ i_cal_time_get_second (itt),
comp_summary, uid_str, rid_str);
}
} else {
*out_sort_key = g_strdup_printf ("%s-%04d%02d%02d%02d%02d%02d-%s-%s",
prefix,
- itt ? i_cal_timetype_get_year (itt) : 0,
- itt ? i_cal_timetype_get_month (itt) : 0,
- itt ? i_cal_timetype_get_day (itt) : 0,
- itt ? i_cal_timetype_get_hour (itt) : 0,
- itt ? i_cal_timetype_get_minute (itt) : 0,
- itt ? i_cal_timetype_get_second (itt) : 0,
+ itt ? i_cal_time_get_year (itt) : 0,
+ itt ? i_cal_time_get_month (itt) : 0,
+ itt ? i_cal_time_get_day (itt) : 0,
+ itt ? i_cal_time_get_hour (itt) : 0,
+ itt ? i_cal_time_get_minute (itt) : 0,
+ itt ? i_cal_time_get_second (itt) : 0,
uid_str, rid_str);
}
@@ -612,7 +612,7 @@ etdp_get_component_root_paths (EToDoPane *to_do_pane,
ICalTimezone *default_zone)
{
ECalComponentDateTime *dt;
- ICalTimetype *itt;
+ ICalTime *itt;
GtkTreePath *first_root_path = NULL;
GtkTreeModel *model;
GSList *roots = NULL;
@@ -858,7 +858,7 @@ etdp_get_comp_colors (EToDoPane *to_do_pane,
if (dt && e_cal_component_datetime_get_value (dt)) {
ICalTimezone *default_zone;
- ICalTimetype *itt, *now;
+ ICalTime *itt, *now;
gboolean is_date;
default_zone = e_cal_data_model_get_timezone (to_do_pane->priv->events_data_model);
@@ -1387,7 +1387,7 @@ static void
etdp_check_time_changed (EToDoPane *to_do_pane,
gboolean force_update)
{
- ICalTimetype *itt;
+ ICalTime *itt;
ICalTimezone *zone;
guint new_today;
@@ -1488,7 +1488,7 @@ etdp_check_time_changed (EToDoPane *to_do_pane,
gchar *markup;
guint date_mark;
- tm = icaltimetype_to_tm (itt);
+ tm = e_cal_util_i_cal_time_to_tm (itt);
i_cal_time_adjust (itt, 1, 0, 0, 0);
@@ -1823,7 +1823,7 @@ etdp_new_common (EToDoPane *to_do_pane,
gtk_tree_model_get (model, &iter, COLUMN_DATE_MARK, &date_mark, -1);
if (date_mark > 0) {
- ICalTimetype *now;
+ ICalTime *now;
ICalTimezone *zone;
gint time_divisions_secs;
@@ -1831,9 +1831,9 @@ etdp_new_common (EToDoPane *to_do_pane,
zone = e_cal_data_model_get_timezone (to_do_pane->priv->events_data_model);
now = i_cal_time_current_time_with_zone (zone);
- i_cal_timetype_set_year (now, date_mark / 10000);
- i_cal_timetype_set_month (now, (date_mark / 100) % 100);
- i_cal_timetype_set_day (now, date_mark % 100);
+ i_cal_time_set_year (now, date_mark / 10000);
+ i_cal_time_set_month (now, (date_mark / 100) % 100);
+ i_cal_time_set_day (now, date_mark % 100);
/* The date_mark is the next day, not the day it belongs to */
i_cal_time_adjust (now, -1, 0, 0, 0);
diff --git a/src/calendar/gui/e-week-view-main-item.c b/src/calendar/gui/e-week-view-main-item.c
index cb290a85fd..3c051766ca 100644
--- a/src/calendar/gui/e-week-view-main-item.c
+++ b/src/calendar/gui/e-week-view-main-item.c
@@ -94,7 +94,7 @@ week_view_main_item_draw_day (EWeekViewMainItem *main_item,
if (!today) {
ECalendarView *view;
- ICalTimetype *tt;
+ ICalTime *tt;
ICalTimezone *zone;
view = E_CALENDAR_VIEW (week_view);
@@ -102,9 +102,9 @@ week_view_main_item_draw_day (EWeekViewMainItem *main_item,
/* Check if we are drawing today */
tt = i_cal_time_from_timet_with_zone (time (NULL), FALSE, zone);
- today = g_date_get_year (date) == i_cal_timetype_get_year (tt) &&
- g_date_get_month (date) == i_cal_timetype_get_month (tt) &&
- g_date_get_day (date) == i_cal_timetype_get_day (tt);
+ today = g_date_get_year (date) == i_cal_time_get_year (tt) &&
+ g_date_get_month (date) == i_cal_time_get_month (tt) &&
+ g_date_get_day (date) == i_cal_time_get_day (tt);
g_clear_object (&tt);
}
diff --git a/src/calendar/gui/e-week-view.c b/src/calendar/gui/e-week-view.c
index 9cab73811b..0a0e8399d5 100644
--- a/src/calendar/gui/e-week-view.c
+++ b/src/calendar/gui/e-week-view.c
@@ -515,7 +515,7 @@ timezone_changed_cb (ECalModel *cal_model,
{
ECalendarView *cal_view = (ECalendarView *) user_data;
GDate *first_day_shown;
- ICalTimetype *tt = NULL;
+ ICalTime *tt = NULL;
time_t lower;
EWeekView *week_view = (EWeekView *) cal_view;
@@ -537,7 +537,7 @@ timezone_changed_cb (ECalModel *cal_model,
/* Recalculate the new start of the first week. We just use exactly
* the same time, but with the new timezone. */
- i_cal_timetype_set_date (tt,
+ i_cal_time_set_date (tt,
g_date_get_year (first_day_shown),
g_date_get_month (first_day_shown),
g_date_get_day (first_day_shown));
@@ -2239,13 +2239,13 @@ e_week_view_set_first_day_shown (EWeekView *week_view,
/* See if we need to update the first day shown. */
if (!g_date_valid (&week_view->priv->first_day_shown)
|| g_date_compare (&week_view->priv->first_day_shown, &base_date)) {
- ICalTimetype *start_tt;
+ ICalTime *start_tt;
time_t start_time;
week_view->priv->first_day_shown = base_date;
start_tt = i_cal_time_null_time ();
- i_cal_timetype_set_date (start_tt,
+ i_cal_time_set_date (start_tt,
g_date_get_year (&base_date),
g_date_get_month (&base_date),
g_date_get_day (&base_date));
@@ -3341,7 +3341,7 @@ e_week_view_add_event (ECalClient *client,
AddEventData *add_event_data;
EWeekViewEvent event;
gint num_days;
- ICalTimetype *start_tt, *end_tt;
+ ICalTime *start_tt, *end_tt;
add_event_data = data;
@@ -3381,8 +3381,8 @@ e_week_view_add_event (ECalClient *client,
event.comp_data->instance_start = start;
event.comp_data->instance_end = end;
- event.start_minute = i_cal_timetype_get_hour (start_tt) * 60 + i_cal_timetype_get_minute (start_tt);
- event.end_minute = i_cal_timetype_get_hour (end_tt) * 60 + i_cal_timetype_get_minute (end_tt);
+ event.start_minute = i_cal_time_get_hour (start_tt) * 60 + i_cal_time_get_minute (start_tt);
+ event.end_minute = i_cal_time_get_hour (end_tt) * 60 + i_cal_time_get_minute (end_tt);
if (event.end_minute == 0 && start != end)
event.end_minute = 24 * 60;
@@ -4425,7 +4425,7 @@ e_week_view_event_move (ECalendarView *cal_view,
EWeekViewEvent *event;
gint event_num, adjust_days, current_start_day, current_end_day;
time_t start_dt, end_dt;
- ICalTimetype *start_time, *end_time;
+ ICalTime *start_time, *end_time;
EWeekView *week_view = E_WEEK_VIEW (cal_view);
gboolean is_all_day = FALSE;
@@ -4448,7 +4448,7 @@ e_week_view_event_move (ECalendarView *cal_view,
start_time = i_cal_component_get_dtstart (event->comp_data->icalcomp);
end_time = i_cal_component_get_dtend (event->comp_data->icalcomp);
- if (i_cal_timetype_get_is_date (start_time) && i_cal_timetype_get_is_date (end_time))
+ if (i_cal_time_is_date (start_time) && i_cal_time_is_date (end_time))
is_all_day = TRUE;
current_end_day = e_week_view_get_day_offset_of_event (week_view,end_dt);
@@ -4796,7 +4796,7 @@ e_week_view_on_editing_stopped (EWeekView *week_view,
if (mod == E_CAL_OBJ_MOD_THIS) {
ECalComponentDateTime *dt;
- ICalTimetype *tt = NULL;
+ ICalTime *tt = NULL;
gchar *tzid;
dt = e_cal_component_get_dtstart (comp);
diff --git a/src/calendar/gui/itip-utils.c b/src/calendar/gui/itip-utils.c
index 6cdcbc250d..e498161a35 100644
--- a/src/calendar/gui/itip-utils.c
+++ b/src/calendar/gui/itip-utils.c
@@ -651,13 +651,13 @@ itip_strip_mailto (const gchar *address)
}
static gchar *
-get_label (ICalTimetype *tt,
+get_label (ICalTime *tt,
gboolean use_24_hour_format)
{
gchar buffer[1000];
struct tm tmp_tm;
- tmp_tm = icaltimetype_to_tm (tt);
+ tmp_tm = e_cal_util_i_cal_time_to_tm (tt);
e_time_format_date_and_time (
&tmp_tm, use_24_hour_format, FALSE, FALSE, buffer, 1000);
@@ -1509,7 +1509,7 @@ comp_minimal (ESourceRegistry *registry,
ECalComponentRange *recur_id;
ICalComponent *icomp, *icomp_clone;
ICalProperty *prop;
- ICalTimetype *itt;
+ ICalTime *itt;
const gchar *uid;
GSList *comments;
@@ -1623,7 +1623,7 @@ comp_compliant_one (ESourceRegistry *registry,
gboolean strip_alarms)
{
ECalComponent *clone, *temp_clone;
- ICalTimetype *itt;
+ ICalTime *itt;
clone = e_cal_component_clone (comp);
itt = i_cal_time_from_timet_with_zone (time (NULL), FALSE, i_cal_timezone_get_utc_timezone ());
@@ -1634,15 +1634,15 @@ comp_compliant_one (ESourceRegistry *registry,
if (e_cal_component_has_recurrences (clone) &&
e_cal_component_has_simple_recurrence (clone)) {
GSList *rrule_list;
- ICalRecurrenceType *rt;
+ ICalRecurrence *rt;
rrule_list = e_cal_component_get_rrules (clone);
rt = rrule_list->data;
- itt = i_cal_recurrence_type_get_until (rt);
+ itt = i_cal_recurrence_get_until (rt);
if (itt && !i_cal_time_is_null_time (itt) && i_cal_time_is_date (itt)) {
ECalComponentDateTime *dt;
- ICalTimetype *dtvalue;
+ ICalTime *dtvalue;
ICalTimezone *from_zone = NULL, *to_zone;
dt = e_cal_component_get_dtstart (clone);
@@ -1665,16 +1665,16 @@ comp_compliant_one (ESourceRegistry *registry,
to_zone = i_cal_timezone_get_utc_timezone ();
- i_cal_timetype_set_time (itt,
- i_cal_timetype_get_hour (dtvalue),
- i_cal_timetype_get_minute (dtvalue),
- i_cal_timetype_get_second (dtvalue));
- i_cal_timetype_set_is_date (itt, FALSE);
+ i_cal_time_set_time (itt,
+ i_cal_time_get_hour (dtvalue),
+ i_cal_time_get_minute (dtvalue),
+ i_cal_time_get_second (dtvalue));
+ i_cal_time_set_is_date (itt, FALSE);
i_cal_timezone_convert_time (itt, from_zone, to_zone);
i_cal_time_set_timezone (itt, to_zone);
- i_cal_recurrence_type_set_until (rt, itt);
+ i_cal_recurrence_set_until (rt, itt);
e_cal_component_datetime_free (dt);
e_cal_component_set_rrules (clone, rrule_list);
@@ -2544,7 +2544,7 @@ reply_to_calendar_comp (ESourceRegistry *registry,
dtstart = e_cal_component_get_dtstart (comp);
if (dtstart && e_cal_component_datetime_get_value (dtstart)) {
- ICalTimetype *itt;
+ ICalTime *itt;
itt = e_cal_component_datetime_get_value (dtstart);
@@ -2661,7 +2661,7 @@ itip_publish_begin (ECalComponent *pub_comp,
}
static gboolean
-check_time (ICalTimetype *tmval,
+check_time (ICalTime *tmval,
gboolean can_null_time)
{
gboolean valid;
@@ -2672,11 +2672,11 @@ check_time (ICalTimetype *tmval,
}
valid = i_cal_time_is_valid_time (tmval) &&
- i_cal_timetype_get_month (tmval) >= 1 && i_cal_timetype_get_month (tmval) <= 12 &&
- i_cal_timetype_get_day (tmval) >= 1 && i_cal_timetype_get_day (tmval) <= 31 &&
- i_cal_timetype_get_hour (tmval) >= 0 && i_cal_timetype_get_hour (tmval) < 24 &&
- i_cal_timetype_get_minute (tmval) >= 0 && i_cal_timetype_get_minute (tmval) < 60 &&
- i_cal_timetype_get_second (tmval) >= 0 && i_cal_timetype_get_second (tmval) < 60;
+ i_cal_time_get_month (tmval) >= 1 && i_cal_time_get_month (tmval) <= 12 &&
+ i_cal_time_get_day (tmval) >= 1 && i_cal_time_get_day (tmval) <= 31 &&
+ i_cal_time_get_hour (tmval) >= 0 && i_cal_time_get_hour (tmval) < 24 &&
+ i_cal_time_get_minute (tmval) >= 0 && i_cal_time_get_minute (tmval) < 60 &&
+ i_cal_time_get_second (tmval) >= 0 && i_cal_time_get_second (tmval) < 60;
g_clear_object (&tmval);
diff --git a/src/calendar/gui/tag-calendar.c b/src/calendar/gui/tag-calendar.c
index 6a0fd87fc1..e1a3936988 100644
--- a/src/calendar/gui/tag-calendar.c
+++ b/src/calendar/gui/tag-calendar.c
@@ -229,7 +229,7 @@ encode_timet_to_julian (time_t t,
gboolean is_date,
const ICalTimezone *zone)
{
- ICalTimetype *tt;
+ ICalTime *tt;
guint32 res;
if (!t)
@@ -242,9 +242,9 @@ encode_timet_to_julian (time_t t,
return 0;
}
- res = encode_ymd_to_julian (i_cal_timetype_get_year (tt),
- i_cal_timetype_get_month (tt),
- i_cal_timetype_get_day (tt));
+ res = encode_ymd_to_julian (i_cal_time_get_year (tt),
+ i_cal_time_get_month (tt),
+ i_cal_time_get_day (tt));
g_clear_object (&tt);
@@ -394,7 +394,7 @@ get_component_julian_range (ECalClient *client,
guint32 *start_julian,
guint32 *end_julian)
{
- ICalTimetype *instance_start = NULL, *instance_end = NULL;
+ ICalTime *instance_start = NULL, *instance_end = NULL;
time_t start_tt, end_tt;
const ICalTimezone *zone;
@@ -899,8 +899,8 @@ prepare_tag (ECalendar *ecal,
{
gint start_year, start_month, start_day;
gint end_year, end_month, end_day;
- ICalTimetype *start_tt = NULL;
- ICalTimetype *end_tt = NULL;
+ ICalTime *start_tt = NULL;
+ ICalTime *end_tt = NULL;
if (clear_first)
e_calendar_item_clear_marks (e_calendar_get_item (ecal));
@@ -912,13 +912,13 @@ prepare_tag (ECalendar *ecal,
return FALSE;
start_tt = i_cal_time_null_time ();
- i_cal_timetype_set_date (start_tt,
+ i_cal_time_set_date (start_tt,
start_year,
start_month + 1,
start_day);
end_tt = i_cal_time_null_time ();
- i_cal_timetype_set_date (end_tt,
+ i_cal_time_set_date (end_tt,
end_year,
end_month + 1,
end_day);
@@ -947,8 +947,8 @@ prepare_tag (ECalendar *ecal,
* called from e_cal_generate_instances() */
static gboolean
tag_calendar_cb (ICalComponent *comp,
- ICalTimetype *instance_start,
- ICalTimetype *instance_end,
+ ICalTime *instance_start,
+ ICalTime *instance_end,
gpointer user_data,
GCancellable *cancellable,
GError **error)
@@ -980,12 +980,12 @@ tag_calendar_cb (ICalComponent *comp,
e_calendar_item_mark_days (
closure->calitem,
- i_cal_timetype_get_year (instance_start),
- i_cal_timetype_get_month (instance_start) - 1,
- i_cal_timetype_get_day (instance_start),
- i_cal_timetype_get_year (instance_end),
- i_cal_timetype_get_month (instance_end) - 1,
- i_cal_timetype_get_day (instance_end),
+ i_cal_time_get_year (instance_start),
+ i_cal_time_get_month (instance_start) - 1,
+ i_cal_time_get_day (instance_start),
+ i_cal_time_get_year (instance_end),
+ i_cal_time_get_month (instance_end) - 1,
+ i_cal_time_get_day (instance_end),
style, TRUE);
return TRUE;
@@ -1050,7 +1050,7 @@ tag_calendar_by_comp (ECalendar *ecal,
tag_calendar_cb,
alloced_closure, (GDestroyNotify) g_free);
} else {
- ICalTimetype *start, *end;
+ ICalTime *start, *end;
start = i_cal_time_from_timet_with_zone (closure.start_time, FALSE, display_zone);
end = i_cal_time_from_timet_with_zone (closure.end_time, FALSE, display_zone);
diff --git a/src/calendar/importers/icalendar-importer.c b/src/calendar/importers/icalendar-importer.c
index a6be631009..d0082e21fa 100644
--- a/src/calendar/importers/icalendar-importer.c
+++ b/src/calendar/importers/icalendar-importer.c
@@ -1187,7 +1187,7 @@ format_dt (const ECalComponentDateTime *dt,
GHashTable *timezones,
ICalTimezone *users_zone)
{
- ICalTimetype *tt;
+ ICalTime *tt;
struct tm tm;
g_return_val_if_fail (timezones != NULL, NULL);
@@ -1197,23 +1197,23 @@ format_dt (const ECalComponentDateTime *dt,
tt = e_cal_component_datetime_get_value (dt);
- i_cal_timetype_set_zone (tt, NULL);
+ i_cal_time_set_timezone (tt, NULL);
if (e_cal_component_datetime_get_tzid (dt)) {
const gchar *tzid = e_cal_component_datetime_get_tzid (dt);
- i_cal_timetype_set_zone (tt, g_hash_table_lookup (timezones, tzid));
+ i_cal_time_set_timezone (tt, g_hash_table_lookup (timezones, tzid));
- if (!i_cal_timetype_get_zone (tt))
- i_cal_timetype_set_zone (tt, i_cal_timezone_get_builtin_timezone_from_tzid (tzid));
+ if (!i_cal_time_get_timezone (tt))
+ i_cal_time_set_timezone (tt, i_cal_timezone_get_builtin_timezone_from_tzid (tzid));
- if (!i_cal_timetype_get_zone (tt) && g_ascii_strcasecmp (tzid, "UTC") == 0)
- i_cal_timetype_set_zone (tt, i_cal_timezone_get_utc_timezone ());
+ if (!i_cal_time_get_timezone (tt) && g_ascii_strcasecmp (tzid, "UTC") == 0)
+ i_cal_time_set_timezone (tt, i_cal_timezone_get_utc_timezone ());
}
- if (i_cal_timetype_get_zone (tt))
- tm = icaltimetype_to_tm_with_zone (tt, i_cal_timetype_get_zone (tt), users_zone);
+ if (i_cal_time_get_timezone (tt))
+ tm = e_cal_util_i_cal_time_to_tm_with_zone (tt, i_cal_time_get_timezone (tt), users_zone);
else
- tm = icaltimetype_to_tm (tt);
+ tm = e_cal_util_i_cal_time_to_tm (tt);
return e_datetime_format_format_tm ("calendar", "table", i_cal_time_is_date (tt) ? DTFormatKindDate :
DTFormatKindDateTime, &tm);
}
@@ -1360,7 +1360,7 @@ preview_comp (EWebViewPreview *preview,
if (percent >= 0) {
tmp = NULL;
if (percent == 100) {
- ICalTimetype *completed;
+ ICalTime *completed;
completed = e_cal_component_get_completed (comp);
diff --git a/src/e-util/e-timezone-dialog.c b/src/e-util/e-timezone-dialog.c
index 8533abc346..92858e9e43 100644
--- a/src/e-util/e-timezone-dialog.c
+++ b/src/e-util/e-timezone-dialog.c
@@ -528,13 +528,13 @@ zone_display_name_with_offset (const ICalTimezone *zone)
{
const gchar *display_name;
struct tm local;
- ICalTimetype *tt;
+ ICalTime *tt;
gint offset;
gchar buffer[100];
time_t now = time (NULL);
gmtime_r ((const time_t *) &now, &local);
- tt = tm_to_icaltimetype (&local, TRUE);
+ tt = e_cal_util_tm_to_i_cal_time (&local, TRUE);
offset = i_cal_timezone_get_utc_offset ((ICalTimezone *) zone, tt, NULL);
g_clear_object (&tt);
diff --git a/src/modules/alarm-notify/alarm-notify.c b/src/modules/alarm-notify/alarm-notify.c
index 5176357014..281151d3ae 100644
--- a/src/modules/alarm-notify/alarm-notify.c
+++ b/src/modules/alarm-notify/alarm-notify.c
@@ -104,7 +104,7 @@ alarm_notify_module_format_time_cb (EReminderWatcher *watcher,
g_return_if_fail (*inout_buffer != NULL);
g_return_if_fail (buffer_size > 0);
- tm = icaltimetype_to_tm (itt);
+ tm = e_cal_util_i_cal_time_to_tm (itt);
text = e_datetime_format_format_tm ("calendar", "table", itt->is_date ? DTFormatKindDate :
DTFormatKindDateTime, &tm);
if (text) {
diff --git a/src/modules/calendar/e-cal-shell-view-private.c b/src/modules/calendar/e-cal-shell-view-private.c
index b691e7cfc5..f7b22aadaa 100644
--- a/src/modules/calendar/e-cal-shell-view-private.c
+++ b/src/modules/calendar/e-cal-shell-view-private.c
@@ -60,7 +60,7 @@ cal_shell_view_get_current_time (ECalendarItem *calitem,
tt = icaltime_from_timet_with_zone (time (NULL), FALSE, timezone);
- return icaltimetype_to_tm (&tt);
+ return e_cal_util_i_cal_time_to_tm (&tt);
}
static void
diff --git a/src/modules/itip-formatter/itip-view.c b/src/modules/itip-formatter/itip-view.c
index 0fa4c12fe9..521b04674e 100644
--- a/src/modules/itip-formatter/itip-view.c
+++ b/src/modules/itip-formatter/itip-view.c
@@ -6522,7 +6522,7 @@ itip_view_init_view (ItipView *view)
} else
from_zone = NULL;
- start_tm = icaltimetype_to_tm_with_zone (datetime.value, from_zone, to_zone);
+ start_tm = e_cal_util_i_cal_time_to_tm_with_zone (datetime.value, from_zone, to_zone);
itip_view_set_start (view, &start_tm, datetime.value->is_date);
view->priv->start_time = icaltime_as_timet_with_zone (*datetime.value, from_zone);
@@ -6568,7 +6568,7 @@ itip_view_init_view (ItipView *view)
icaltime_adjust (datetime.value, -1, 0, 0, 0);
}
- end_tm = icaltimetype_to_tm_with_zone (datetime.value, from_zone, to_zone);
+ end_tm = e_cal_util_i_cal_time_to_tm_with_zone (datetime.value, from_zone, to_zone);
itip_view_set_end (view, &end_tm, datetime.value->is_date);
view->priv->end_time = icaltime_as_timet_with_zone (*datetime.value, from_zone);
diff --git a/src/plugins/save-calendar/csv-format.c b/src/plugins/save-calendar/csv-format.c
index a79ab459df..f255d5fb09 100644
--- a/src/plugins/save-calendar/csv-format.c
+++ b/src/plugins/save-calendar/csv-format.c
@@ -149,7 +149,7 @@ add_time_to_csv (GString *line,
if (time) {
gboolean needquotes = FALSE;
- struct tm mytm = icaltimetype_to_tm (time);
+ struct tm mytm = e_cal_util_i_cal_time_to_tm (time);
gchar *str = (gchar *) g_malloc (sizeof (gchar) * 200);
/* Translators: the %F %T is the third argument for a
diff --git a/src/plugins/save-calendar/rdf-format.c b/src/plugins/save-calendar/rdf-format.c
index ef4e4a1415..366969a2eb 100644
--- a/src/plugins/save-calendar/rdf-format.c
+++ b/src/plugins/save-calendar/rdf-format.c
@@ -133,7 +133,7 @@ add_time_to_rdf (xmlNodePtr node,
{
if (time) {
xmlNodePtr cur_node = NULL;
- struct tm mytm = icaltimetype_to_tm (time);
+ struct tm mytm = e_cal_util_i_cal_time_to_tm (time);
gchar *str = (gchar *) g_malloc (sizeof (gchar) * 200);
gchar *tmp = NULL;
gchar *timezone;
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]
diff --git a/src/calendar/gui/e-day-view.c b/src/calendar/gui/e-day-view.c
index 025db92730..dd24033191 100644
--- a/src/calendar/gui/e-day-view.c
+++ b/src/calendar/gui/e-day-view.c
@@ -575,7 +575,7 @@ e_day_view_get_work_day_range_for_day (EDayView *day_view,
if (day >= 0 && day < e_day_view_get_days_shown (day_view)) {
GDateWeekday weekday;
- ICalTimetype *tt;
+ ICalTime *tt;
tt = i_cal_time_from_timet_with_zone (day_view->day_starts[day], FALSE,
e_calendar_view_get_timezone (E_CALENDAR_VIEW (day_view)));
@@ -759,7 +759,7 @@ day_view_new_event_in_selected_range_cb (ECalModel *model,
ECalComponent *comp = NULL;
gint day, event_num;
ECalComponentDateTime *start_dt, *end_dt;
- ICalTimetype *start_tt, *end_tt;
+ ICalTime *start_tt, *end_tt;
const gchar *uid, *use_tzid;
AddEventData add_event_data;
ESourceRegistry *registry;
@@ -786,8 +786,8 @@ day_view_new_event_in_selected_range_cb (ECalModel *model,
if (ned->in_top_canvas) {
use_tzid = NULL;
- i_cal_timetype_set_is_date (start_tt, 1);
- i_cal_timetype_set_is_date (end_tt, 1);
+ i_cal_time_set_is_date (start_tt, 1);
+ i_cal_time_set_is_date (end_tt, 1);
/* Editor default in day/work-week view - top canvas */
e_cal_component_set_transparency (comp, E_CAL_COMPONENT_TRANSP_TRANSPARENT);
@@ -2801,7 +2801,7 @@ timezone_changed_cb (ECalModel *cal_model,
ICalTimezone *new_zone,
gpointer user_data)
{
- ICalTimetype *tt;
+ ICalTime *tt;
time_t lower;
EDayView *day_view = (EDayView *) user_data;
ECalendarView *cal_view = (ECalendarView *) day_view;
@@ -3717,7 +3717,7 @@ e_day_view_find_work_week_start (EDayView *day_view,
guint offset;
GDateWeekday weekday;
GDateWeekday first_work_day;
- ICalTimetype *tt = NULL;
+ ICalTime *tt = NULL;
ICalTimezone *zone;
time_t res;
@@ -3748,7 +3748,7 @@ e_day_view_find_work_week_start (EDayView *day_view,
tt = i_cal_time_null_time ();
- i_cal_timetype_set_date (tt,
+ i_cal_time_set_date (tt,
g_date_get_year (&date),
g_date_get_month (&date),
g_date_get_day (&date));
@@ -3767,7 +3767,7 @@ e_day_view_recalc_day_starts (EDayView *day_view,
gint day;
gchar *str;
gint days_shown;
- ICalTimetype *tt;
+ ICalTime *tt;
GDate dt;
days_shown = e_day_view_get_days_shown (day_view);
@@ -3784,7 +3784,7 @@ e_day_view_recalc_day_starts (EDayView *day_view,
tt = i_cal_time_from_timet_with_zone (day_view->day_starts[0], FALSE, e_calendar_view_get_timezone
(E_CALENDAR_VIEW (day_view)));
g_date_clear (&dt, 1);
- g_date_set_dmy (&dt, i_cal_timetype_get_day (tt), i_cal_timetype_get_month (tt),
i_cal_timetype_get_year (tt));
+ g_date_set_dmy (&dt, i_cal_time_get_day (tt), i_cal_time_get_month (tt), i_cal_time_get_year (tt));
/* To Translators: the %d stands for a week number, it's value between 1 and 52/53 */
str = g_strdup_printf (_("Week %d"), g_date_get_iso8601_week_of_year (&dt));
gtk_label_set_text (GTK_LABEL (day_view->week_number_label), str);
@@ -5759,7 +5759,7 @@ e_day_view_add_event (ESourceRegistry *registry,
EDayViewEvent event;
gint day, offset;
gint days_shown;
- ICalTimetype *start_tt, *end_tt;
+ ICalTime *start_tt, *end_tt;
ICalTimezone *zone;
AddEventData *add_event_data;
@@ -5807,8 +5807,8 @@ e_day_view_add_event (ESourceRegistry *registry,
* display. */
offset = add_event_data->day_view->first_hour_shown * 60
+ add_event_data->day_view->first_minute_shown;
- event.start_minute = i_cal_timetype_get_hour (start_tt) * 60 + i_cal_timetype_get_minute (start_tt) -
offset;
- event.end_minute = i_cal_timetype_get_hour (end_tt) * 60 + i_cal_timetype_get_minute (end_tt) -
offset;
+ event.start_minute = i_cal_time_get_hour (start_tt) * 60 + i_cal_time_get_minute (start_tt) - offset;
+ event.end_minute = i_cal_time_get_hour (end_tt) * 60 + i_cal_time_get_minute (end_tt) - offset;
g_clear_object (&start_tt);
g_clear_object (&end_tt);
@@ -7608,7 +7608,7 @@ e_day_view_event_move (ECalendarView *cal_view,
gint time_divisions;
gint day, event_num, resize_start_row, resize_end_row;
time_t start_dt, end_dt;
- ICalTimetype *start_time, *end_time;
+ ICalTime *start_time, *end_time;
day_view = E_DAY_VIEW (cal_view);
day = day_view->editing_event_day;
@@ -8030,7 +8030,7 @@ e_day_view_on_editing_stopped (EDayView *day_view,
if (olddt && e_cal_component_datetime_get_value (olddt) &&
i_cal_time_get_timezone (e_cal_component_datetime_get_value
(olddt))) {
- ICalTimetype *itt;
+ ICalTime *itt;
itt = e_cal_component_datetime_get_value (olddt);
@@ -8039,7 +8039,7 @@ e_day_view_on_editing_stopped (EDayView *day_view,
i_cal_time_is_date (itt),
i_cal_time_get_timezone (itt)),
g_strdup (e_cal_component_datetime_get_tzid (olddt)));
} else {
- ICalTimetype *itt;
+ ICalTime *itt;
ICalTimezone *zone;
zone = e_calendar_view_get_timezone (E_CALENDAR_VIEW
(day_view));
@@ -8059,7 +8059,7 @@ e_day_view_on_editing_stopped (EDayView *day_view,
if (olddt && e_cal_component_datetime_get_value (olddt) &&
i_cal_time_get_timezone (e_cal_component_datetime_get_value
(olddt))) {
- ICalTimetype *itt;
+ ICalTime *itt;
itt = e_cal_component_datetime_get_value (olddt);
@@ -8068,7 +8068,7 @@ e_day_view_on_editing_stopped (EDayView *day_view,
i_cal_time_is_date (itt),
i_cal_time_get_timezone (itt)),
g_strdup (e_cal_component_datetime_get_tzid (olddt)));
} else {
- ICalTimetype *itt;
+ ICalTime *itt;
ICalTimezone *zone;
zone = e_calendar_view_get_timezone (E_CALENDAR_VIEW
(day_view));
@@ -8122,7 +8122,7 @@ e_day_view_convert_grid_position_to_time (EDayView *day_view,
{
ECalendarView *cal_view;
gint time_divisions;
- ICalTimetype *tt;
+ ICalTime *tt;
time_t val;
gint minutes;
@@ -8139,13 +8139,13 @@ e_day_view_convert_grid_position_to_time (EDayView *day_view,
if (minutes == 60 * 24)
return day_view->day_starts[col + 1];
/* Create an ICalTimetype and convert to a time_t. */
tt = i_cal_time_from_timet_with_zone (
day_view->day_starts[col],
FALSE, e_calendar_view_get_timezone (E_CALENDAR_VIEW (day_view)));
- i_cal_timetype_set_hour (tt, minutes / 60);
- i_cal_timetype_set_minute (tt, minutes % 60);
- i_cal_timetype_set_second (tt, 0);
+ i_cal_time_set_hour (tt, minutes / 60);
+ i_cal_time_set_minute (tt, minutes % 60);
+ i_cal_time_set_second (tt, 0);
val = i_cal_time_as_timet_with_zone (tt, e_calendar_view_get_timezone (E_CALENDAR_VIEW (day_view)));
@@ -8161,7 +8161,7 @@ e_day_view_convert_time_to_grid_position (EDayView *day_view,
gint *row)
{
ECalendarView *cal_view;
- ICalTimetype *tt;
+ ICalTime *tt;
gint time_divisions;
gint day, minutes;
gint days_shown;
@@ -8184,12 +8184,12 @@ e_day_view_convert_time_to_grid_position (EDayView *day_view,
}
}
/* To find the row we need to convert the time to an ICalTimetype,
* calculate the offset in minutes from the top of the display and
* divide it by the mins per row setting. */
tt = i_cal_time_from_timet_with_zone (time, FALSE, e_calendar_view_get_timezone (E_CALENDAR_VIEW
(day_view)));
- minutes = i_cal_timetype_get_hour (tt) * 60 + i_cal_timetype_get_minute (tt);
+ minutes = i_cal_time_get_hour (tt) * 60 + i_cal_time_get_minute (tt);
minutes -= day_view->first_hour_shown * 60 + day_view->first_minute_shown;
g_clear_object (&tt);
@@ -9218,7 +9218,7 @@ e_day_view_on_top_canvas_drag_data_received (GtkWidget *widget,
ECalObjModType mod = E_CAL_OBJ_MOD_ALL;
ECalClient *client;
GtkWindow *toplevel;
- ICalTimetype *itt;
+ ICalTime *itt;
ICalTimezone *zone;
num_days = 1;
@@ -9302,7 +9302,7 @@ e_day_view_on_top_canvas_drag_data_received (GtkWidget *widget,
dt = day_view->day_starts[day] + start_offset * 60;
itt = i_cal_time_from_timet_with_zone (dt, FALSE, zone);
if (all_day_event) {
- i_cal_timetype_set_is_date (itt, TRUE);
+ i_cal_time_set_is_date (itt, TRUE);
date = e_cal_component_datetime_new_take (itt, NULL);
} else {
date = e_cal_component_datetime_new_take (itt,
@@ -9317,7 +9317,7 @@ e_day_view_on_top_canvas_drag_data_received (GtkWidget *widget,
dt = day_view->day_starts[day + num_days - 1] + end_offset * 60;
itt = i_cal_time_from_timet_with_zone (dt, FALSE, zone);
if (all_day_event) {
- i_cal_timetype_set_is_date (itt, TRUE);
+ i_cal_time_set_is_date (itt, TRUE);
date = e_cal_component_datetime_new_take (itt, NULL);
} else {
date = e_cal_component_datetime_new_take (itt,
@@ -8139,13 +8139,13 @@ e_day_view_convert_grid_position_to_time (EDayView *day_view,
if (minutes == 60 * 24)
return day_view->day_starts[col + 1];
- /* Create an ICalTimetype and convert to a time_t. */
+ /* Create an ICalTime and convert to a time_t. */
tt = i_cal_time_from_timet_with_zone (
day_view->day_starts[col],
@@ -8184,12 +8184,12 @@ e_day_view_convert_time_to_grid_position (EDayView *day_view,
}
}
- /* To find the row we need to convert the time to an ICalTimetype,
+ /* To find the row we need to convert the time to an ICalTime,
* calculate the offset in minutes from the top of the display and
* divide it by the mins per row setting. */